package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut


__DATA__
M?T5,1@$"`0D````````````"`!0````!`8`E*````#0``-[\```````T`"``
M!@`H`!P`&P````8````T`8``-`&``#0```#@````X`````4````$`````P``
M`10!@`$4`8`!%````!4````5````!`````$````!``````&````!@`````!\
MZ```?.@````%``$```````$``(```8&```&!@````%S4``!D>`````<``0``
M`````@``V[`!@=NP`8';L````/@```#X````!@````0````$```!+`&``2P!
M@`$L````&````!@````$````!```````````````````````````````````
M````````+VQI8F5X96,O;&0M96QF+G-O+C$`````````"`````0````!1G)E
M94)31```##CH````Q0```-<```#`````4````(8```!`````H@```),```"_
M````F0```((````H````D0```+T`````````<P```!X````]````L@```(P`
M``")````U````%(```!L````90``````````````N0````````!%````;0``
M`(@```!Q`````````````````````````(\```!;````T````%H```#-````
MD@```!P```"[````A0`````````9`````````%$```"\````````````````
M````)@````````!@``````````````!Y````U0```*$```"?````Q@```&\`
M``#+`````````$8```!R````C0```*8`````````N@``````````````````
M``````#$`````````&<```#"````"0````````````````````````!N````
M`````````````````````($``````````````"P```````````````````".
M`````````$D```"O`````@`````````X````?P``````````````````````
M````````K````````````````````%T``````````````,X`````````R```
M`,,````8````Q0```"\`````````J0`````````3``````````````"P````
M`````"0```"G````I0```+4``````````````$X```!8````T0````````!B
M````1P```(<`````````N````````````````````&L`````````M@```-8`
M````````G@```#(```!F````R@```-,```"S````E````(0```"T````0@``
M``````!6````%0```&D```"W````G````,\```"K````%`````4```"8````
M80```'@```!4````=````,<```#)````HP```)T```!5````,0```'`````P
M````FP```'L```"N````=0```*@````K`````````,$```#,````````````
M````````````````````````````````````````````````````````````
M``````````````````T````````````````````````````````````1````
M```````````2````````````````````!@`````````````````````````#
M``````````````````````````````````````````<``````````````"``
M```````````````````````````````````6````$```````````````*0``
M```````````````````````````````````````7````````````````````
M!```````````````#P```#L``````````0````````!$`````````!H`````
M````/``````````W`````````#X````Y````````````````````````````
M````````,P`````````E````"@``````````````````````````````````
M``X``````````````"T``````````````",````````````````````J````
M``````````!>``````````P```````````````````!<````/P```#H`````
M``````````````!W`````````'P`````````````````````````-0``````
M``````````````L````A````30````````!*`````````(L```"`````````
M`#0```!H````9````"X```"#`````````$L```!?````E0```)<`````````
M``````````"0`````````$P```"@````'P``````````````00```*0`````
M````0P````@`````````)P```$\``````````````%D`````````(@```)H`
M````````-@```*H`````````E@``````````````````````````````?0``
M`*T```!^`````````&,```````````````````"Q````=@```!L```"^````
M2````(H`````````4P```'H````=`````````&H```!7`````````-(`````
M``````````````````````````P!@=U8````=!(```````+E`8'=8````'P2
M```````&4`&`=I`````\$@``"P``".(!@'=H````%!(```L```:P`8!VL```
M`!P2```+````%P&!W6@```@H$@``````!0P!@'8<````&!(```L```:8`8!V
MJ````"02```+```(<@&`=T@````T$@``"P```"D!@=S4`````1$``!<```."
M`8'=<````#@2```````%;`&`=D````!`$@``"P``"2\!@%J$```"1!(```L`
M``8L`8!VA````$@2```+```'D@&`=O@````L$@``"P``"`(!@'<H````5!(`
M``L```6T`8!V6````"@2```+````0`&!V[``````$0#_\0```O@!@=UX````
M`!(```````:D`8!VK````"`2```+```$<`&`=>@```!,$@``"P``!S`!@';<
M````2!(```L```.P`8!UI````$02```+```&[`&`=L0````($@``"P``!Q0!
M@';4````4!(```L```,%`8'=@````%02```````#/@&!W8@```!P$@``````
M"#H!@'<X````1!(```L```!)`8'=D```!%02```````#[`&`=;@````P$@``
M"P```%<!@=V8```!-!(```````1\`8!U[````$@2```+```(U`&`=V0````8
M$@``"P``"!X!@'<P````3!(```L```1``8!UU````!02```+````8P&!W:``
M``%D$@``````"3P!@'&$````#!(```L```!T`8'<V`````01```7```(Q@&`
M=V`````<$@``"P``!>0!@'9H````&!(```L```>N`8!W`````"02```+```'
MY@&`=Q`````4$@``"P``!80!@'9(````.!(```L```*&`8'@,````"`1```9
M````?@&!W:@```9@$@```````(T!@=S<````!!$``!<```>$`8!V]````#`2
M```+```%&`&`=B`````4$@``"P``!0`!@'88````'!(```L```8@`8!V@```
M`$P2```+```)30&`4M0```"4$@``"P```)<!@=VP```#X!(```````.D`8!U
MH````$@2```+```)6P&`70````&H$@``"P``!#0!@'70````&!(```L```-,
M`8'=N`````P2```````'!@&`=M````!4$@``"P``!50!@'8X````2!(```L`
M``=V`8!V\````#02```+```#'`&!W<````MP$@```````_@!@'6\````+!(`
M``L```"E`8'<X`````$1```7```)C`&`)/0`````$@``"@``!9P!@'90````
M,!(```L```"R`8'=R```!=`2```````&^`&`=LP```!8$@``"P``!G0!@':<
M````,!(```L```.\`8!UJ````$`2```+````O0&!W=````#,$@```````,H!
M@=W8```!U!(```````#8`8'="`````01```7````X`&!W>````,0$@``````
M`PT!@=WH````;!(```````,5`8'=\``````2```````%S`&`=F`````@$@``
M"P``!:@!@'94````+!(```L```EG`8!A>````EP2```+```(9`&`=T0````X
M$@``"P```.L!@=WX````)!(```````.8`8!UG````$P2```+```)=`&`<9``
M``.0$@``"P``")P!@'=4````*!(```L```F*`8!U(````#@2```+```(N`&`
M=UP````@$@``"P``!/0!@'84````(!(```L```?8`8!W#````!@2```+```(
MC@&`=U`````L$@``"P``"(`!@'=,````,!(```L```3$`8!V!````#`2```+
M```#-P&!W@`````T$@```````NT!@=S,````!!$``!8```C\`8`E*````-@2
M```+```)`P&!Y'@`````$`#_\0```^`!@'6T````-!(```L```-T`8'>"```
M```2```````"^0&!WA``````$@``````!L@!@':X````%!(```L```HI`8)<
MT``````1```6```#5@&!WA@````D$@``````!4@!@'8T````3!(```L```1,
M`8!UV````!`2```+```#10&!WB````#$$@``````"9(!@&/4```,R!(```L`
M``9<`8!VE````#@2```+```&:`&`=I@````T$@``"P```/H!@=XH```$M!(`
M``````+``8'>,``````2```````(+`&`=S0```!($@``"P```DX!@=XX````
M7!(```````+.`8'>0````+@2```````'6@&`=N@````\$@``"P``"9\!@%ZH
M````D!(```L```1D`8!UX`````@2```+```"_@&!WD@```"H$@```````0,!
M@=SA`````1$``!<```2X`8!V`````#02```+```#7@&!WE````!$$@``````
M`1$!@=Y8```#_!(```````$A`8'<Y`````01```7```&U`&`=KP````0$@``
M"P``"/<!@=S4`````!``__$```2@`8!U^````#P2```+```"8`&!WF````!X
M$@``````":L!@%\X```"0!(```L```/4`8!UL````#@2```+```)L`&`61@`
M``%L$@``"P```G`!@=SH````!!$``!<```7P`8!V;````!02```+```)P@&`
M<)P```#H$@``"P``!=@!@'9D````'!(```L```24`8!U]````$`2```+```'
MO`&`=P0````@$@``"P```3$!@=SL`````1$``!<```60`8!V3````#02```+
M```'(@&`=M@```!,$@``"P``!%@!@'7<````#!(```L```0<`8!UR````"`2
M```+```%/`&`=BP````($@``"P``!-P!@'8,````*!(```L```00`8!UQ```
M`"02```+```!/`&`=^@`````$```#````4(!@=YH```9)!(```````H@`8'>
M<````#P2```````'R@&`=P@````<$@``"P```R0!@=SP````!!$``!<```);
M`8'>>````+@2```````#R`&`=:P````\$@``"P```GX!@=Z````!B!(`````
M``4D`8!V)````!`2```+```'/@&`=N````!$$@``"P```5`!@=Z(````8!(`
M``````:\`8!VM````!@2```+```#;P&!WI````!4$@```````Y(!@=Z8````
M`!(```````(,`8'>H```!J`2```````&@`&`=J`````L$@``"P``!.@!@'80
M````)!(```L```%@`8'>J````'@2```````(\`&!W-0`````$`#_\0```I\!
M@=ZP```!B!(```````%K`8'<P``````1`/_Q```'H`&`=OP````H$@``"P``
M"00!@>1X`````!``__$```5X`8!V1````#P2```+```"Q@&!WK@```"D$@``
M`````8$!@=ST`````1$``!<```&,`8'@4````!,1```9```"I@&!W/@````$
M$0``%P```A@!@=[````'D!(```````*Y`8'>R``````2```````$K`&`=?P`
M```X$@``"P``"=@!@=T,````!!$``!<```GE`8!3:````#02```+```%8`&`
M=CP```!$$@``"P```9L!@=[0````M!(```````+4`8'>V````"@2```````'
M]`&`=R0```!8$@``"P``!`0!@'7`````*!(```L```H!`8`F^````&`2```+
M```!L@&!W/P````$$0``%P```VT!@=[@````/!(```````8(`8!V=`````P2
M```+```$B`&`=?````!$$@``"P``"@X!@%S(````.!(```L```&X`8'=````
M``01```7```"F`&!WN@`````$@``````!TP!@';D````0!(```L```'#`8'>
M\````S@2```````%_`&`=G`````0$@``"P```=$!@=T$````!!$``!<```7`
M`8!V7````"02```+```#>P&!WO@```$X$@``````!3`!@'8H````#!(```L`
M``A6`8!W0````#P2```+```&X`&`=L`````,$@``"P```XD!@=\`````Q!(`
M``````=H`8!V[````#@2```+```($`&`=RP```!0$@``"P```E8!@=\(````
MF!(```````BJ`8!W6````"02```+```$T`&`=@@````L$@``"P``!C@!@':(
M````1!(```L```'>```````````@```````#90&!WQ````!\$@```````?(!
M@=\8````2!(```````*P`8'?(``````2```````&C`&`=J0````H$@``"P``
M`@`!@=\H````8!(```````HT`8#\Z``````1```.```"$P&!WS````!($@``
M````!D0!@':,````0!(```L```0H`8!US````!P2```+```(2`&`=SP```!`
M$@``"P``!A0!@'9X````"!(```L`;&EB<&5R;"YS;P!097)L7V-R;V%K`%!E
M<FQ?<W9?,G!V7V9L86=S`%!,7W!E<FQ?9&5S=')U8W1?;&5V96P`7T193D%-
M24,`4&5R;%]A=E]S:&EF=`!097)L7VUG7W-E=`!097)L7VYE=UA37V9L86=S
M`%!,7V-O;7!C=@!P97)L7V-O;G-T<G5C=`!03%]P87)S97(`4&5R;%]D;W5N
M=VEN9`!03%]D;U]U;F1U;7``<&5R;%]P87)S90!097)L7VYE=U-6<'8`4&5R
M;%]S=E]S971P=@!E;G9I<F]N`%!E<FQ?;F5W6%,`4&5R;%]S>7-?:6YI=#,`
M<&5R;%]R=6X`4$Q?97AI=%]F;&%G<P!B;V]T7T1Y;F%,;V%D97(`4$Q?8W5R
M<W1A8VMI;F9O`%!,7W1A:6YT960`7V9I;FD`<&5R;%]D97-T<G5C=`!097)L
M7V=V7V9E=&-H<'8`<&5R;%]A;&QO8P!?1TQ/0D%,7T]&1E-%5%]404),15\`
M4$Q?:6Y?979A;`!03%]M96UO<GE?=W)A<`!097)L7W-A=F5?9&5S=')U8W1O
M<E]X`%!,7V]P`%!,7W1O<%]E;G8`4&5R;%]A=E]F971C:`!03%]E=F%L7W)O
M;W0`7TIV7U)E9VES=&5R0VQA<W-E<P!097)L7W-Y<U]T97)M`%!E<FQ?<V%F
M97-Y<VUA;&QO8P!P97)L7V9R964`;&EB;2YS;RXU`&QI8F-R>7!T+G-O+C4`
M;&EB=71I;"YS;RXX`&QI8G1H<BYS;RXS`%]?97)R;W(`<F5A9`!O<&5N`&-L
M;W-E`&QI8F,N<V\N-P!?7VUB7W-B7VQI;6ET`&UE;6UO=F4`7U]S=&%C:U]C
M:&M?9W5A<F0`9V5T<&ED`&UE;6-P>0!?7W-T9&5R<G``<F5A9&QI;FL`9V5T
M=6ED`')M9&ER`')E861D:7(`;'-E96L`7U]S=&%C:U]C:&M?9F%I;`!F<')I
M;G1F`%]?<')O9VYA;64`;'-T870`<W1R<W1R`'-T<FYC;7``<W1R;F-P>0!U
M;FQI;FL`<F5A;&QO8P!?0W5R<F5N=%)U;F5,;V-A;&4`<W1R=&]K`'-T<F1U
M<`!M96US970`7VEN:71?=&QS`&]P96YD:7(`<W1R8VUP`'-P<FEN=&8`871E
M>&ET`&%C8V5S<P!S=')L96X`97AE8W9P`&-L;W-E9&ER`&UK9&ER`%]S879E
M9G!R7S$T`%]S879E9G!R7S$U`%]S879E9G!R7S$V`%]S879E9G!R7S$W`%]S
M879E9G!R7S$X`%]S879E9G!R7S$Y`%]S879E9G!R7S(P`%]S879E9G!R7S(Q
M`%]S879E9G!R7S(R`%]S879E9G!R7S(S`%]S879E9G!R7S(T`%]S879E9G!R
M7S(U`%]S879E9G!R7S(V`%]S879E9G!R7S(W`%]S879E9G!R7S(X`%]S879E
M9G!R7S(Y`%]S879E9G!R7S,P`%]S879E9G!R7S,Q`%]S879E9W!R7S$T`%]S
M879E9W!R7S$U`%]S879E9W!R7S$V`%]S879E9W!R7S$W`%]S879E9W!R7S$X
M`%]S879E9W!R7S$Y`%]S879E9W!R7S(P`%]S879E9W!R7S(Q`%]S879E9W!R
M7S(R`%]S879E9W!R7S(S`%]S879E9W!R7S(T`%]S879E9W!R7S(U`%]S879E
M9W!R7S(V`%]S879E9W!R7S(W`%]S879E9W!R7S(X`%]S879E9W!R7S(Y`%]S
M879E9W!R7S,P`%]S879E9W!R7S,Q`%]R97-T9G!R7S$T`%]R97-T9G!R7S$U
M`%]R97-T9G!R7S$V`%]R97-T9G!R7S$W`%]R97-T9G!R7S$X`%]R97-T9G!R
M7S$Y`%]R97-T9G!R7S(P`%]R97-T9G!R7S(Q`%]R97-T9G!R7S(R`%]R97-T
M9G!R7S(S`%]R97-T9G!R7S(T`%]R97-T9G!R7S(U`%]R97-T9G!R7S(V`%]R
M97-T9G!R7S(W`%]R97-T9G!R7S(X`%]R97-T9G!R7S(Y`%]R97-T9G!R7S,P
M`%]R97-T9G!R7S,Q`%]R97-T9W!R7S$T`%]R97-T9W!R7S$U`%]R97-T9W!R
M7S$V`%]R97-T9W!R7S$W`%]R97-T9W!R7S$X`%]R97-T9W!R7S$Y`%]R97-T
M9W!R7S(P`%]R97-T9W!R7S(Q`%]R97-T9W!R7S(R`%]R97-T9W!R7S(S`%]R
M97-T9W!R7S(T`%]R97-T9W!R7S(U`%]R97-T9W!R7S(V`%]R97-T9W!R7S(W
M`%]R97-T9W!R7S(X`%]R97-T9W!R7S(Y`%]R97-T9W!R7S,P`%]R97-T9W!R
M7S,Q`%]R97-T9G!R7S$T7W@`7W)E<W1F<')?,35?>`!?<F5S=&9P<E\Q-E]X
M`%]R97-T9G!R7S$W7W@`7W)E<W1F<')?,3A?>`!?<F5S=&9P<E\Q.5]X`%]R
M97-T9G!R7S(P7W@`7W)E<W1F<')?,C%?>`!?<F5S=&9P<E\R,E]X`%]R97-T
M9G!R7S(S7W@`7W)E<W1F<')?,C1?>`!?<F5S=&9P<E\R-5]X`%]R97-T9G!R
M7S(V7W@`7W)E<W1F<')?,C=?>`!?<F5S=&9P<E\R.%]X`%]R97-T9G!R7S(Y
M7W@`7W)E<W1F<')?,S!?>`!?<F5S=&9P<E\S,5]X`%]R97-T9W!R7S$T7W@`
M7W)E<W1G<')?,35?>`!?<F5S=&=P<E\Q-E]X`%]R97-T9W!R7S$W7W@`7W)E
M<W1G<')?,3A?>`!?<F5S=&=P<E\Q.5]X`%]R97-T9W!R7S(P7W@`7W)E<W1G
M<')?,C%?>`!?<F5S=&=P<E\R,E]X`%]R97-T9W!R7S(S7W@`7W)E<W1G<')?
M,C1?>`!?<F5S=&=P<E\R-5]X`%]R97-T9W!R7S(V7W@`7W)E<W1G<')?,C=?
M>`!?<F5S=&=P<E\R.%]X`%]R97-T9W!R7S(Y7W@`7W)E<W1G<')?,S!?>`!?
M<F5S=&=P<E\S,5]X`%]E9&%T80!?7V)S<U]S=&%R=`!?7V5N9``O=7-R+VQO
M8V%L+VQI8B]P97)L-2\U+C$R+C0O;6%C:"]#3U)%`'!A<E]I;FET7V5N=@!P
M87)?8W5R<F5N=%]E>&5C`'!A<E]E;G9?8VQE86X`<&%R7V1I<FYA;64`<&%R
M7V9I;F1P<F]G`%A37TEN=&5R;F%L<U]005)?0D]/5`!X<U]I;FET`'!A<E]M
M:W1M<&1I<@!P87)?8VQE86YU<`!M86EN`'!A<E]S971U<%]L:6)P871H`'!A
M<E]C=7)R96YT7V5X96-?<')O8P!?7W!S7W-T<FEN9W,`6%-?26YT97)N86QS
M7U!!4E]#3$5!4E-404-+`'!A<E]B87-E;F%M90!G971?=7-E<FYA;65?9G)O
M;5]G971P=W5I9`!?4T1!7T)!4T5?`%]31$$R7T)!4T5?`$9"4T1?,2XP````
M``````(``0`!``$````!``$``0````(``0`!``$``0`!``$``0`"``$``0`!
M``$``0`!``(``@`!`````0````$``0`!``$````!`````0`!``$``0`!``(`
M``````$``0`!``$``0````$``0`!``(``0`!``$``@`!`````0`!`````0`!
M``$```````$````"``(``0`!``$``0````$``0`!``$``0`!``$``0`!``$`
M`@`!``$``0`!``(``@`!``$``@`!``$``@`!``$``0````(``0`#``(``0`!
M``$``@````$``@```````0`!``$``P`!``$``0`"``$``0`!``$``0````$`
M`0`!``$``0`!``$``0````(``0`"``,``0`"``$``0````$``@`"``(``0`!
M`````0`"``$``0`!``$``@```````@`"``(``0`!``$``0````(``0`!``$`
M```"``$``0`!`````@`!`````0````$``@`!``$``0`"``$``0`#``$``0`!
M`````@````(``0````$````!``$``0`!``$``0```D(````0````(`=Z*+``
M```#```*0````````0`!```"9@```!``````!WHHL`````(```I```````&!
MW-0```H3``````&!W-@``"83``````&!W-P``"X3``````&!W.```#X3````
M``&!W.$``',3``````&!W.0``'<3``````&!W.@``'\3``````&!W.P``(43
M``````&!W/```)$3``````&!W/0``*83``````&!W/@``*@3``````&!W/P`
M`+03``````&!W0```+D3``````&!W00``+X3``````&!X#```"P3``````&!
MX%```*<3``````&!W5@```$5``````&!W6````(5``````&!W6@```85````
M``&!W7````L5``````&!W7@``!,5``````&!W8```!H5``````&!W8@``!L5
M``````&!W9```!T5``````&!W9@``!\5``````&!W:```"05``````&!W:@`
M`"T5``````&!W;```#05``````&!W;@``#@5``````&!W<```#P5``````&!
MW<@``$$5``````&!W=```$45``````&!W=@``$85``````&!W>```$@5````
M``&!W>@``$D5``````&!W?```$H5``````&!W?@``$\5``````&!W@```%H5
M``````&!W@@``%\5``````&!WA```&`5``````&!WA@``&,5``````&!WB``
M`&85``````&!WB@``&H5``````&!WC```&L5``````&!WC@``&T5``````&!
MWD```&X5``````&!WD@``'(5``````&!WE```'45``````&!WE@``'85````
M``&!WF```'L5``````&!WF@``(X5``````&!WG```(\5``````&!WG@``)(5
M``````&!WH```)05``````&!WH@``)<5``````&!WI```)D5``````&!WI@`
M`)H5``````&!WJ```)L5``````&!WJ@``)X5``````&!WK```*`5``````&!
MWK@``*45``````&!WL```*D5``````&!WL@``*H5``````&!WM```*\5````
M``&!WM@``+`5``````&!WN```+45``````&!WN@``+H5``````&!WO```+P5
M``````&!WO@``,`5``````&!WP```,05``````&!WP@``,<5``````&!WQ``
M`,P5``````&!WQ@``,T5``````&!WR```,X5``````&!WR@``-`5``````&!
MWS```-(5`````)0A__!\"`*FD^$`#)`!`!1\/PMX2``!C4@`4G&!80``@`L`
M!'P(`Z:#Z__\?6%;>$Z``""4(?_@?`@"ICT@`8*3H0`4?'T;>9/!`!A\XSMX
MD^$`''R^*WB0`0`D?)\C>)"IW0A`@0!8@20``"^)``!!G@!,/6`!@I$KW,R(
M"0``+X```$&>`#@Y*0`!2```%(@)```Y*0`!+X```$&>`"`O@``O0)[_[)$K
MW,R("0``.2D``2^```!`GO_H+X@``$&>``P](`&"D0G=##T@`8(Y*=NP+XD`
M`$&>`"Q(`;D1/&`!@#AC=^A(`;D%2___%7_D^WA_Q?-X?Z/K>$@`.4E(`;B=
M2`&WP4O__]B4(?_P?`@"II/!``@_P`&"D`$`%(@>X&.3X0`,+X```$">`$`_
MX`&"@7^``($K```OB0``09X`)#@+``1]*0.FD!^``$Z`!"&!?X``@2L``"^)
M``!`GO_D.````9@>X&.``0`4@\$`"(/A``Q\"`.F."$`$$Z``"!\"`*FE"'_
M\)`!`!2``0`4."$`$'P(`Z9.@``@?`@"II0A__`](`&".&G<N)`!`!2`"=RX
M+X```$&>`!P](```.2D``"^)``!!G@`,?2D#IDZ`!"&``0`4."$`$'P(`Z9.
M@``@?`@"II0A__"0`0`4@`$`%#@A`!!\"`.F3H``()0A__!\:AMXB`,``"^`
M``!!G@!$/2`!@#AC``&!:7APB2L``$@``!2(`P``.&,``2^```!!G@`@?X!(
M`$">_^R(`P``?&H;>#AC``$O@```0)[_Z'U#4W@X(0`03H``('P(`J:4(?S@
M..,`.#C!`%"1P0+8D`$#)#@```B1X0+<?`D#II(!`N!\R#-XDB$"Y))!`NB2
M80+LDH$"\)*A`O22P0+XDN$"_),!`P"3(0,$DT$#")-A`PR3@0,0DZ$#%)/!
M`QB3X0,<D&$`1($G```X````@4<`!#CG``B1*``$D`@`")%(``R0"```.0@`
M$$(`_]P[A@)H.Z$`N($=_]R`'0`$@/W_V(%]``!]"@)X@-W_J("]_ZQ\Z5IX
M@)W_F'S)2GB`??^<?*I2>'R)2GA\:E)X52`(/%5(#_Y52@@\?`Q#>#@```!]
MC%-XD!T`&)&=`!P[O0`(?YW@`$">_Z"`80!$/\!:@F/>>9D_X%J"@2,`&&/_
M>9F!0P`<@.,`(($#`"21(0`0D4$`%($A`%"!00!4@B$`;'V(4!1]9TD4@.,`
M`($#``1\:1MXD.$`2'R,\A21`0!,?`P@$'P``1"#P0`4?```T(#)``R`J0`(
M@T,`$'S(,/B#8P`4?*<H^(&!`!!_22@X?VHP.'T(\#A\YV`X?0A3>'SG2WB!
M00!D@2$`8'UC6WB!80!,?&`:%'[[4!1^VDD4@2$`2%5]+OZ"`0!H52`H-#D@
M``!\"NMX@`$`3'ZW^A1^U+-X5`PH-#P`6H)]2F-X8`!YF7V$4!1]8TD4?'>H
M$'QC&1"#X0!T?ZQ`%'^+.12!80!(@8$`3%2D\`)4R/"^?&,`T#C@``!\B$-X
M?6E8^%3&\`)^@Z(4@&$`3#N```!]"#-X?2G0.'UD6WA\^E@X?8I@^'\Q`A1]
M2M@X?UI+>'T;8#A7BR@T5&GPOE>F+OY4@/`"?WM3>'WQR!!][WD05ZHH-(/!
M`'!\!$MX5&SP`GUF,WA\A&-X.&```'S&4WA][P#0?XG@^'^JZ/A_BQ@X?ZP@
M.'\/@A1]*3@X?4I`.'WY0!1]V#D4?2E;>(#A`!!]2F-X@6$`6#P`6H*!@0!<
M8`!YF8$!`!1^M5`4?I1)%'[_`A2"(0"`?4A@%'TG610XH```?FH"%'P*F!!\
M``$0?3)+>'P``-!^0)(45X#P`GU3V!1],M$4?A^X$'X0@1""00"$?RHP%'\)
M*10[````5ZGPOGP&2WA7&R@T5RPN_E>]\`)\QNMX.*```%<J*#1_;&-X?P?`
M^'\HR/A_"2@X?8Q3>'SG&#A_*C`X?0@@.'SG2WA]"%-X@2$`?'X0`-`Y8```
M/4!:@G]U8!1_5%D4?M#R%#M```!A2GF9?_<@%'_6&11^KT`4?HXY%)/!`#A_
MJ5(45T@H-%=J+OZ3X0`\?FGH$'YSF1"#X0!X5VPH-(#A`(A]"E-X.2```'U*
M8WA^<P#0?950%'UT211_D_H4.6```($!`(Q]73`4?3PI%%5D*#15ER[^D4$`
M-'R7NWA5BB@T?O=3>#U`6H)A2GF9/`!:@GYH4A1@`'F9??("%'P(F!!\``$0
M?')X$'QC&1"#X0"458CPOI$A`#!_==CX?/([>'P``-!71_`"?`@#IGSD0WA5
MBO`"?K4P.%=F\+Y\A%-X?.8S>%=J\`)\QE-X/0!:@GU(`J9\8P#080AYF7W#
MBA1_5-#X?C]"%%<H\+Y^E"@X?.A#>#B@``!^2I(45SGP`GU3,!1],BD4?0C+
M>'UK*#B100`L?9U@^'Z46WB!00`P?8PP.(%A`#1_O4`X?WM`.'Z<HWA_O6-X
M?K7;>(&!`#Q_:^@4?TKA%(%A`#@ZP```D2$`*'P?B!!\``$0?4RH%'TKH12#
MP0"0?RJX%'\)L12#X0"<?RK(^)#A``Q_+"`X.P```#C@``!_T/-X?4HP.'_`
M`-`\`%J"?,]`%'RN.117'2@T@>$`I'U*8WA^B:-X5RPN_F``>9E^IE`4?H5)
M%'Y_`A17*B@T@<$`H'^L8WA\_Y@0?.<Y$'V,4W@Y8```?.<`T'S;8!1\NED4
M5PKP`CA@``!\Z`.F?AZ"%%3,+OY7._"^?3$@%'T0&12100`(?ZQC>'U;VWA4
MRB@TD2$`)#B@``"!(0"8?8Q3>'_H`J9\US#X.6```#_`6H*1`0`@8]YYF7T5
M8!1\]%D4?O<@.#C@``!4I/`"5-WPOGZO\A14X"@T?3)+>'R=ZWA5!"[^?`D#
MIE3*\`)^7Y(4?`0C>(/A`*Q\#Z@0?``!$%<Y\`)_>\MX@>$`M'^]4W@[@```
M?+8H^'T,0/A]U'-X?```T'SIX#A]"N@X?C_R%'Z`HA1^UA@X?8S8.'[62WA\
M'X@0?``!$($A`"!_]>@4?]3A%'V,4WB!00`DD\$`&'S&V#B3X0`<?LNS>(/!
M`"A^JF`4?HE9%(/A`"Q^]S-X50KP`E4&\+Y5""@T?9^X%'U^L11\"`.F?(1#
M>%3@\`(X8```?0P@%'SK&11\&3-X?SE3>'_H`J9]"D#X?0S(.#M```!]2N@X
M?-/8%'RRT11^R;-X?4IC>(`!`*A_IE`4?X5)%'S)`J95#"[^@<$`L%4**#0X
MX```?,QC>%3D\`)5`_"^?8Q3>#E@``!\FQMX?-5@%'RT6115"/`"?WM#>(#A
M`!A\RC#X?,S8.($!`!Q]2L@X?LFS>'U*8WA^J%`4?H=)%'T)`J94RB[^@D$`
MS%3,*#0\8%J"?0I3>'__`-!]2F-X.*```&!C>9DY(```?N\:%'X?`A1\G5`4
M?'Q)%%2@\`)4R?"^?!U+>%3&\`)_O3-X?,D"IE2*+OXX8```5(PH-#N```!\
MRE-X.T```'U*8WA\9QCX?(@@^#D@``!\U5`4?+1)%#L```!\:>`X?(KH.'SG
MT#A]"-@X?_'(%'_0P11\YTMX@2$`O'T(4W@]0%J"?K]`%'Z>.11]"0*F84IY
MF8(!`,1_*5(4?F^X$'YSF1!4RB[^@>$`P%3,*#1^<P#0?0I3>'[3<A1]2F-X
M?FG($'YSF1`Y(```@8$`N'_WV!1_UM$45(CPOG]U4!1_5$D4@B$`R%1I\`*!
MP0#P.*```'TH0WA4A/`"..```'T((WA]F&-X?*LH^'S,,/A\B0*F?*DX.'S*
M0#A]:^`X?8SH.'UK2WA]C%-X5VHN_GZ_8!1^GED4?G,`T%=L*#2#X0#L?(I3
M>'\3PA1]2F-X.2```'\YZ!1_&.$45,3POG^U4!1_E$D45*GP`CM```!])"-X
M5,;P`CT@6H)\A#-X.&```']+T/A_;-CX82EYF7]J(#A\TDH4?6LX.'])&#A]
MC$`X?6M+>'V,4W@\`%J"?KE@%'Z8611@`'F9?RD"IG[P`A17JB[^?G"X$'YS
MF1!7K"@T?G,`T((!`-1]]GMX?RI3>'[3LA1]2F-X.2```#N```!_-5`4?Q1)
M%'ZW0!1^ECD4@>$`T%=)\`)7:/"^?2A#>%=[\`(]0%J"?0C;>#C@``!_B^#X
M?ZSH^&%*>9E_:0*F?O!2%'^).#A_JD`X?6L8.'V,(#A^<C`0?G.9$'UK2WA]
MC%-X@D$`W%<J+OY^M6`4?I19%'YS`-!7+"@T?B6+>']J4WA\LRH4?4IC>#D@
M``!_=5`4?U1)%'ZF(!1^A1D4?(D"IH(A`-A7B?`"5Z;POCL```!])C-X5[WP
M`CB@``!\QNMX?PO`^'\LR/A_"2@X?RHP.'UK.#A]C$`X?G"X$'YSF1!]:TMX
M@@$`Y'V,4WA7:B[^?K5@%'Z4611^<P#05VPH-'WV>WA\BE-X?M.R%'U*8W@Y
M(```.T```'R54!1\=$D4?K=`%'Z6.12!X0#@5PGP`E<H\+Y]*$-X5SGP`C_`
M6H)]",MX..```&/>>9E_2]#X?VS8^'\I`J9_LO(4?TDX.']J0#A]:R@X?8PP
M.'YRZ!!^<YD0?6M+>'V,4WB#P0#H5(HN_GZU8!1^E%D4?G,`T%2,*#1_*E-X
M?Y.*%'U*8W@Y(```?ETP%'X\*11_-5`4?Q1)%'^I`J972?`"5V;POE=[\`)]
M)C-X/2!:@GS&VWA\C"#X82EYF3A@``!^OTH4?(HP.'V,0#@\`%J".*```'V,
M4WA@`'F9?5^H$'U*41!\:QCX?4@#IG[P`A1\:2@X?6LX.'YPN!!^<YD0?6M+
M>(/A`/Q7*B[^?W)@%']1611^<P#0?6@"IE<L*#1]]GMX?ZI3>'[3LA1]2F-X
M.2```'^[4!1_FDD4?W=`%']6.12!X0#T5&GP`E2(\+X[````?6L`T'TH0WA4
MA/`"?0@C>#C@``!]:`.F?RS(^'\+P/A_"3@X?RI`.'UK*#A]C#`X?6M+>'V,
M4WA\B0*F?GM@%'Y:611_U/-X?8@"IE>J+OY\BE-X.2```#N````^(&[9?HRB
M%%>L*#1]2F-X8C'KH7]S4!1_4DD4?G4P%'Y4*12#P0#X5PGP`E<F\+Y])C-X
M5SGP`GS&RW@XH```?XO@^'^LZ/A^[XH4?XDH.'^J,#A]:S@X?8Q`.'QON!!\
M8QD0?6M+>('A`01]C%-X5VHN_GZS8!1^DED4?&,`T%=L*#2``0%D?=9S>'R*
M4WA^P[(4?4IC>#D@``!]ET`4?78Y%'R54!1\=$D4@<$!`%>)\`)7J/"^5[WP
M`GTH0W@XX```?0CK>#M```!\Z2IX?0HR>'^I`J9_/XH4?2G2>'U*VGA^K%`4
M?HM)%'Y_R!!^<YD0@^$!#%2*+OY4C"@T?G,`T'_8\WA_JE-X?Q/"%'U*8W@Y
M(```?[50%'^4211]F3`4?7@I%(/!`0A72?`"5V;POGTF,WA7>_`"?,;;>#B@
M```X8```?*DZ>'S*0GA_:0*F?N^*%'TI&GA]2B)X?F^X$'YSF1!^K%`4?HM)
M%('A`117JB[^5ZPH-'YS`-!]UG-X?VI3>'[3LA1]2F-X.2```'V70!1]=CD4
M?W50%']4212!P0$05&GP`E2(\+Y4A/`"?2A#>#C@``!]""-X.X```'SI*GA]
M"C)X?(D"IG\_BA1]*>)X?4KJ>'ZL4!1^BTD4?G_($'YSF1"#X0$<5VHN_E=L
M*#1^<P#0?]CS>'R*4WA_$\(4?4IC>#D@``!\E5`4?'1)%'V9,!1]>"D4@\$!
M&%>)\`)7IO"^?28S>%>]\`)\QNMX.*```#M```!\J3IX?,I">'^I`J9^[XH4
M?2G2>'U*VGA^;[@0?G.9$'ZL4!1^BTD4@>$!)%2*+OY4C"@T?G,`T'W6<WA_
MJE-X?M.R%'U*8W@Y(```?9=`%'UV.11_M5`4?Y1)%('!`2!72?`"5VCPOE=[
M\`)]*$-X..```'T(VW@X8```?.DJ>'T*,GA_:0*F?S^*%'TI&GA]2B)X?JQ0
M%'Z+211^?\@0?G.9$(/A`2Q7JB[^5ZPH-'YS`-!_V/-X?VI3>'\3PA1]2F-X
M.2```']U4!1_5$D4?9DP%'UX*12#P0$H5&GP`E2&\+Y])C-X5(3P`GS&(W@X
MH```.X```'RI.GA\RD)X?(D"IG[OBA1]*>)X?4KJ>'YON!!^<YD0?JQ0%'Z+
M212!X0$T5VHN_E=L*#1^<P#0?=9S>'R*4WA^T[(4?4IC>#D@``!]ET`4?78Y
M%'R54!1\=$D4@<$!,%>)\`)7J/"^5[WP`GTH0W@XX```?0CK>#M```!\Z2IX
M?0HR>'^I`J9_/XH4?2G2>'U*VGA^K%`4?HM)%'Y_R!!^<YD0@^$!/%2*+OY4
MC"@T?G,`T'_8\WA_JE-X?Q/"%'U*8W@Y(```?[50%'^4211]F3`4?7@I%(/!
M`3A72?`"5V;POGTF,WA7>_`"?,;;>#B@```X8```?*DZ>'S*0GA_:0*F?N^*
M%'TI&GA]2B)X?F^X$'YSF1!^K%`4?HM)%('A`417JB[^5ZPH-'YS`-!]UG-X
M?VI3>'[3LA1]2F-X.2```'V70!1]=CD4?W50%']4212!P0%`5&GP`E2(\+Y4
MA/`"?2A#>#C@``!]""-X.X```'SI*GA]"C)X?(D"IG\_BA1]*>)X?4KJ>'ZL
M4!1^BTD4?G_($'YSF1"#X0%,5VHN_E=L*#1^<P#0?]CS>'R*4WA_$\(4?4IC
M>#D@``!\E5`4?'1)%'V9,!1]>"D4@\$!2%>)\`)7IO"^?28S>%>]\`)\QNMX
M.*```#M```!\J3IX?,I">'^I`J9^[XH4?2G2>'U*VGA^;[@0?G.9$'ZL4!1^
MBTD4@>$!5%2*+OY4C"@T?G,`T'W6<WA_JE-X?M.R%'U*8W@Y(```?9=`%'UV
M.11_M5`4?Y1)%('!`5!72?`"5VCPOE=[\`)]*$-X..```'T(VW@X8```?.DJ
M>'T*,GA_:0*F?S^*%'TI&GA]2B)X?JQ0%'Z+211^?\@0?G.9$(/A`5Q7JB[^
M5ZPH-'YS`-!_V/-X?VI3>'\3PA1]2F-X.2```']U4!1_5$D4?9DP%'UX*12#
MP0%85&GP`E2&\+Y])C-X5(3P`GS&(W@XH```.X```'RI.GA\RD)X?(D"IG[O
MBA1]*>)X?4KJ>'YON!!^<YD0?JQ0%'Z+2117:B[^5VPH-'YS`-!\BE-X?M-R
M%'U*8W@Y(```?)50%'QT211]ET`4?78Y%('!`8A7B?`"5ZCPOGTH0WA7O?`"
M?0CK>#C@```[0```?.DJ>'T*,GA_J0*F?S^*%'TITGA]2MIX?G_($'YSF1!^
MK%`4?HM)%(/A`6Q4BB[^5(PH-'YS`-!_V/-X?ZI3>'\3PA1]2F-X.2```'V9
M,!1]>"D4?[50%'^4212!00%@5TGP`H/!`6A79O"^5WOP`GTF,W@XH```?,;;
M>#A@``!\J3IX?593>']I`J9\RD)X?N"*%'TI&GA]2B)X?>"X$'WO>1!^;%`4
M?DM)%(`!`717JB[^5ZPH-'WO`-!_:E-X?L^R%'U*8W@Y(```?S-0%'\2211]
MET`4?78Y%%1I\`)4B/"^?2A#>%2$\`)]""-X..```#N```!\Z2IX?0HR>'R)
M`J9]*>)X?4KJ>']L4!1_2TD45RHN_GZ_BA17+"@T?(I3>'W_J!!][WD0?4IC
M>#D@``"#X0%\?)M0%'QZ211][P#0@2$!<'_4\WA^CZ(4.P```'V5,!1]="D4
M?39+>%>F\+Z#P0%X5XGP`E>]\`)])C-X.*```'S&ZWA\J3IX?,I">'^I`J9^
MX(H4?2G">'U*RGA]X+@0?>]Y$'YL4!1^2TD4?`D"IE2*+OY4C"@T?>\`T'^J
M4WA^S[(4?4IC>#D@``!_<U`4?U))%'V70!1]=CD4@4$!A%<)\`)7*/"^?2A#
M>%<Y\`)]",MX..```'[JBA0X8```?.DJ>'T*,GA^OXH4?2D:>'U*(GA_GZ@0
M?YSA$'\L4!1_"TD4@6$!A%=J+OZ!X0&,5VPH-'^<`-!_JE-X?ISR%'U*8W@Y
M(```?[E0%'^8211^:[@0?G.9$(/!`8!]E3`4?70I%%1I\`)4AO"^@^$`1'TF
M,WA4A/`"?,8C>#B@```[0```?*DZ>'S*0GA\B0*F?2G2>'U*VGA^K%`4?HM)
M%%>J+OY7K"@T?G,`T'R*4WA^T_(4?4IC>#D@``!]ET`4?78Y%'R54!1\=$D4
M5VCPOE=)\`)7>_`"?2A#>#C@``!]"-MX.X```'SI*GA]"C)X?VD"IG\OBA1]
M*>)X?4KJ>'[L4!1^RTD4?F_($'YSF1"!80&05(HN_E2,*#1^<P#0?VI3>'\3
M<A1]2F-X.2```'ZY,!1^F"D4?W=0%']6212!@0&45XGP`E>F\+Y7O?`"?28S
M>#B@``!\QNMX.&```'RI.GA\RD)X?ZD"IGTI&GA]2B)X/F"/&SI```!B<[S<
M?S50%'\42117:B[^?NR8%'[+D11_JE-X5VPH-#D@``!]2F-X?K=`%'Z6.11_
MN5`4?YA)%%2(\+Y4:?`"5(3P`GTH0W@XX```?0@C>#M```!\Z2MX?0HS>'SK
M*#A]##`X?TE(.']J4#A\B0*F?2E;>'U*8WB!80&8@8$!G'\U4!1_%$D45ZHN
M_G[LF!1^RY$4?(I3>%>L*#1]2F-X.2```'R94!1\>$D4?K<P%'Z6*1172?`"
M5V;POGTF,WA7>_`"?,;;>#B@```[@```?*D[>'S*0WA\JS@X?,Q`.'^)2#A_
MJE`X?VD"IGTI6WA]2F-X@6$!H'\U4!1_%$D4@8$!I%2*+OY_:E-X.2```'[L
MF!1^RY$45(PH-'U*8WA_>5`4?UA)%'ZW0!1^ECD45XGP`E>H\+Y]*$-X5[WP
M`GT(ZW@XX```.&```'SI*WA]"C-X?.LH.'T,,#A\:4@X?(I0.'^I`J9]*5MX
M?4IC>(%A`:A_-5`4?Q1)%(&!`:Q7:B[^?ZI3>#D@``!^[)@4?LN1%%=L*#1]
M2F-X?[E0%'^8211^MS`4?I8I%%1I\`)4AO"^?28S>%2$\`)\QB-X.*```#M`
M``!\J3MX?,I#>'RK.#A\S$`X?TE(.']J4#A\B0*F?2E;>'U*8WB!80&P?S50
M%'\4212!@0&T5ZHN_GR*4W@Y(```?NR8%'[+D117K"@T?4IC>'R94!1\>$D4
M?K=`%'Z6.1172?`"5VCPOGTH0WA7>_`"?0C;>#C@```[@```?.DK>'T*,WA\
MZR@X?0PP.'^)2#A_JE`X?VD"IGTI6WA]2F-X@6$!N'\U4!1_%$D4@8$!O%2*
M+OY_:E-X.2```'[LF!1^RY$45(PH-'U*8WA_>5`4?UA)%'ZW,!1^EBD45XGP
M`E>F\+Y])C-X5[WP`GS&ZW@XH```.&```'RI.WA\RD-X?*LX.'S,0#A\:4@X
M?(I0.'^I`J9]*5MX?4IC>(%A`<!_-5`4?Q1)%(&!`<17:B[^?ZI3>#D@``!^
M[)@4?LN1%%=L*#1]2F-X?[E0%'^8211^MT`4?I8Y%%1I\`)4B/"^?2A#>%2$
M\`)]""-X..```#M```!\Z2MX?0HS>'SK*#A]##`X?TE(.']J4#A\B0*F?2E;
M>'U*8WB!80'(?S50%'\4212!@0',5ZHN_GR*4W@Y(```?NR8%'[+D117K"@T
M?4IC>'R94!1\>$D4?K<P%'Z6*1172?`"5V;POGTF,WA7>_`"?,;;>#B@```[
M@```?*D[>'S*0WA\JS@X?,Q`.'^)2#A_JE`X?VD"IGTI6WA]2F-X@6$!T'\U
M4!1_%$D4@8$!U%2*+OY_:E-X.2```'[LF!1^RY$45(PH-'U*8WA_>5`4?UA)
M%'ZW0!1^ECD45XGP`E>H\+Y]*$-X5[WP`GT(ZW@XX```.&```'SI*WA]"C-X
M?.LH.'T,,#A\:4@X?(I0.'^I`J9]*5MX?4IC>(%A`=A_-5`4?Q1)%(&!`=Q7
M:B[^?ZI3>#D@``!^[)@4?LN1%%=L*#1]2F-X?[E0%'^8211^MS`4?I8I%%1I
M\`)4AO"^?28S>%2$\`)\QB-X.*```#M```!\J3MX?,I#>'RK.#A\S$`X?TE(
M.']J4#A\B0*F?2E;>'U*8WB!80'@?S50%'\4212!@0'D5ZHN_GR*4W@Y(```
M?NR8%'[+D117K"@T?4IC>'R94!1\>$D4?K=`%'Z6.1172?`"5VCPOGTH0WA7
M>_`"?0C;>#C@```[@```?.DK>'T*,WA\ZR@X?0PP.'^)2#A_JE`X?VD"IGTI
M6WA]2F-X@6$!Z'\U4!1_%$D4@8$![%2*+OY_:E-X.2```'[LF!1^RY$45(PH
M-'U*8WA_>5`4?UA)%'ZW,!1^EBD45XGP`E>F\+Y])C-X5[WP`GS&ZW@XH```
M.&```'RI.WA\RD-X?*LX.'S,0#A\:4@X?(I0.'^I`J9]*5MX?4IC>(%A`?!_
M-5`4?Q1)%(&!`?17:B[^?ZI3>#D@``!^[)@4?LN1%%=L*#1]2F-X?[E0%'^8
M211^MT`4?I8Y%%1I\`)4B/"^?2A#>%2$\`)]""-X..```#M```!\Z2MX?0HS
M>'SK*#A]##`X?TE(.']J4#A\B0*F?2E;>'U*8WB!80'X?S50%'\4212!@0'\
M5ZHN_GR*4W@Y(```?NR8%'[+D117K"@T?4IC>'R94!1\>$D4?K<P%'Z6*117
M2?`"5V;POGTF,WA7>_`"?,;;>#B@```[@```?*D[>'S*0WA\JS@X?,Q`.'^)
M2#A_JE`X?VD"IGTI6WA]2F-X@6$"`'\U4!1_%$D4@8$"!%2*+OY_:E-X.2``
M`'[LF!1^RY$45(PH-'U*8WA_>5`4?UA)%'ZW0!1^ECD45XGP`E>H\+Y]*$-X
M5[WP`GT(ZW@XX```.&```'SI*WA]"C-X?.LH.'T,,#A\:4@X?(I0.'^I`J9]
M*5MX?4IC>(%A`@A_-5`4?Q1)%(&!`@Q7:B[^?ZI3>#D@``!^[)@4?LN1%%=L
M*#1]2F-X?[E0%'^8211^MS`4?I8I%%1I\`)4AO"^?28S>%2$\`)\QB-X.*``
M`#M```!\J3MX?,I#>'RK.#A\S$`X?TE(.']J4#A\B0*F?2E;>'U*8WB!80(0
M?S50%'\4212!@0(45ZHN_GR*4W@Y(```?NR8%'[+D117K"@T?4IC>'R94!1\
M>$D4?K=`%'Z6.1172?`"5VCPOGTH0WA7>_`"?0C;>#C@```[@```?.DK>'T*
M,WA\ZR@X?0PP.'^)2#A_JE`X?VD"IGTI6WA]2F-X@6$"&'[U4!1^U$D4@8$"
M'%2*+OY_:E-X.2```'ZLF!1^BY$45(PH-'U*8WA_-U`4?Q9)%'XU,!1^%"D4
M5XGP`E>F\+Y])C-X5[WP`GS&ZW@XH```.&```'RI.WA\RD-X?*LX.'S,0#A\
M:4@X?(I0.'^I`J9]*5MX?4IC>(%A`B!_<5`4?U!)%(&!`B17*B[^?ZI3>#D@
M``!^[)@4?LN1%%<L*#1]2F-X?[M0%'^:211^MT`4?I8Y%%1I\`)4B/"^?2A#
M>%2$\`)]""-X..```#L```!\Z2MX?0HS>'SK*#A]##`X?PE(.'\J4#A\B0*F
M?2E;>'U*8WB!80(H?O50%'[4212!@0(L5ZHN_GR*4W@Y(```?JR8%'Z+D117
MK"@T?4IC>']W4!1_5DD4?)4P%'QT*117"?`"5R;POGTF,WA7.?`"?,;+>#B@
M```[@```?*D[>'S*0WA\JS@X?,Q`.'^)2#A_JE`X?2E;>'U*8WB!80(P?R10
M%'\#211\B0*F@8$"-#Y@RF(Z0```8G/!UE=J+OY^[)@4?LN1%'R*4WB!80(X
M5VPH-#D@``!]2F-X?K=`%'Z6.11\F5`4?'A)%(&!`CQ7B?`"5ZCPOE>]\`)]
M*$-X..```'T(ZW@[0```?.DJ>'T*,GA_J0*F?2G2>'U*VGA^[)@4?LN1%'\U
M4!1_%$D4@6$"0%2*+OY4C"@T?ZI3>'U*8W@Y(```?[E0%'^8211^MS`4?I8I
M%(&!`D172?`"5V;POGTF,WA7>_`"?,;;>#B@```X8```?*DZ>'S*0GA_:0*F
M?2D:>'U*(GA_-5`4?Q1)%%>J+OY^[)@4?LN1%(%A`DA7K"@T?VI3>#D@``!]
M2F-X?K=`%'Z6.11_>5`4?UA)%(&!`DQ4:?`"5(CPOE2$\`)]*$-X..```'T(
M(W@[@```?.DJ>'T*,GA\B0*F?2GB>'U*ZGA^[)@4?LN1%'\U4!1_%$D4@6$"
M4%=J+OY7;"@T?(I3>'U*8W@Y(```?)E0%'QX211^MS`4?I8I%(&!`E17B?`"
M5Z;POGTF,WA7O?`"?,;K>#B@```[0```?*DZ>'S*0GA_J0*F?2G2>'U*VGA_
M-5`4?Q1)%%2*+OY^[)@4?LN1%(%A`EA4C"@T?ZI3>#D@``!]2F-X?K=`%'Z6
M.11_N5`4?YA)%(&!`EQ72?`"5VCPOE=[\`)]*$-X..```'T(VW@X8```?.DJ
M>'T*,GA_:0*F?2D:>'U*(GA^[)@4?LN1%'\U4!1_%$D4@6$"8%>J+OY7K"@T
M?VI3>'U*8W@Y(```?WE0%']8211^MS`4?I8I%(&!`F14:?`"5(;POGTF,WA4
MA/`"?,8C>#B@```[@```?*DZ>'S*0GA\B0*F?2GB>'U*ZGA_-5`4?Q1)%%=J
M+OY^[)@4?LN1%(%A`FA7;"@T?(I3>#D@``!]2F-X?K=`%'Z6.11\F5`4?'A)
M%(&!`FQ7B?`"5ZCPOE>]\`)]*$-X..```'T(ZW@[0```?.DJ>'T*,GA_J0*F
M?2G2>'U*VGA^[)@4?LN1%'\U4!1_%$D4@6$"<%2*+OY4C"@T?ZI3>'U*8W@Y
M(```?[E0%'^8211^MS`4?I8I%(&!`G172?`"5V;POGTF,WA7>_`"?,;;>#B@
M```X8```?*DZ>'S*0GA_:0*F?2D:>'U*(GA_-5`4?Q1)%%>J+OY^[)@4?LN1
M%(%A`GA7K"@T?VI3>#D@``!]2F-X?K=`%'Z6.11_>5`4?UA)%(&!`GQ4:?`"
M5(CPOE2$\`)]*$-X..```'T((W@[@```?.DJ>'T*,GA\B0*F?2GB>'U*ZGA^
M[)@4?LN1%'\U4!1_%$D4@6$"@%=J+OY7;"@T?(I3>'U*8W@Y(```?)E0%'QX
M211^MS`4?I8I%(&!`H17B?`"5Z;POGTF,WA7O?`"?,;K>#B@```[0```?*DZ
M>'S*0GA_J0*F?2G2>'U*VGA_-5`4?Q1)%%2*+OY^[)@4?LN1%(%A`HA4C"@T
M?ZI3>#D@``!]2F-X?K=`%'Z6.11_N5`4?YA)%(&!`HQ72?`"5VCPOE=[\`)]
M*$-X..```'T(VW@X8```?.DJ>'T*,GA_:0*F?2D:>'U*(GA^[)@4?LN1%'\U
M4!1_%$D4@6$"D%>J+OY7K"@T?VI3>'U*8W@Y(```?WE0%']8211^MS`4?I8I
M%(&!`I14:?`"5(;POGTF,WA4A/`"?,8C>#B@```[@```?*DZ>'S*0GA\B0*F
M?2GB>'U*ZGA_-5`4?Q1)%%=J+OY^[)@4?LN1%(%A`IA7;"@T?(I3>#D@``!]
M2F-X?K=`%'Z6.11\F5`4?'A)%(&!`IQ7B?`"5ZCPOE>]\`)]*$-X..```'T(
MZW@[0```?.DJ>'T*,GA_J0*F?2G2>'U*VGA^[)@4?LN1%'\U4!1_%$D4@6$"
MH%2*+OY4C"@T?ZI3>'U*8W@Y(```?[E0%'^8211^MS`4?I8I%(&!`J172?`"
M5V;POGTF,WA7>_`"?,;;>#B@```X8```?*DZ>'S*0GA_:0*F?2D:>'U*(GA_
M-5`4?Q1)%%>J+OY^[)@4?LN1%(%A`JA7K"@T?VI3>#D@``!]2F-X?K=`%'Z6
M.11_>5`4?UA)%(&!`JQ4:?`"5(CPOE2$\`)]*$-X..```'T((W@[@```?.DJ
M>'T*,GA\B0*F?2GB>'U*ZGA^[)@4?LN1%'\U4!1_%$D4@6$"L%=J+OY7;"@T
M?(I3>'U*8W@Y(```?)E0%'QX211^MS`4?I8I%(&!`K17B?`"5Z;POGTF,WA7
MO?`"?,;K>#B@```[0```?*DZ>'S*0GA_J0*F?2G2>'U*VGA_-5`4?Q1)%%2*
M+OY^[)@4?LN1%(%A`KA4C"@T?ZI3>#D@``!]2F-X?K=`%'Z6.11_N5`4?YA)
M%(&!`KQ72?`"5VCPOE=[\`)]*$-X..```'T(VW@X8```?.DJ>'T*,GA_:0*F
M?2D:>'U*(GA^[)@4?LN1%'\U4!1_%$D4@6$"P%>J+OY7K"@T?VI3>'U*8W@Y
M(```?WE0%']8211^MS`4?I8I%(&!`L14:?`"5(;POGTF,WA4A/`"?,8C>#B@
M```[@```?*DZ>'S*0GA\B0*F?2GB>'U*ZGA_-5`4?Q1)%%=J+OY^[)@4?LN1
M%(%A`LA7;"@T?(I3>#D@``!]2F-X.T```'R94!1\>$D45XGP`E>Y\+Z!@0+,
M?3G+>%>]\`)_.>MX.P```'\)*GA_*C)X?K=`%'Z6.11]*=)X?4K:>%2(+OY^
M]5`4?M1)%'ZLF!1^BY$4?`I#>%2,*#0Y(```?4IC>%=H\+Y_MU`4?Y9)%%=)
M\`)]*$-X5WOP`CC@``!]"-MX?94P%'UT*10X8```?,D"IGSIPGA]"LIX?2D:
M>'U*(GA_;%`4?TM)%%>J+OY7K"@T?,I3>#D@``!]2F-X5&;P`GV;4!1]>DD4
M5(KPOCK@``!\RE-X5(3P`I+_``!]2B-X@&$`2#N```"`@0!,.6```(*_``@Y
M(```@M\`#'S,(!1\JQD4@G\`$(*?`!1\G;`4?'RI%((_`!B"7P`<?8J@%'UI
MF12!_P`@@A\`)'^HD!1_AXD4D-\`!'U9@!1].'D4D)\`#)%?`"21GP`4D[\`
M')+_`""2_P`(DO\`$)+_`!B``0,D@<$"V('A`MQ\"`.F@@$"X((A`N2"00+H
M@F$"[(*!`O""H0+T@L$"^(+A`OR#`0,`@R$#!(-!`PB#80,,@X$#$(.A`Q2#
MP0,8@^$#'#@A`R!.@``@E"'_T'P(`J:3@0`@?'P;>9-!`!A\FB-XDV$`').A
M`"23P0`HD^$`+)`!`#1`@@`P.&```(`!`#2#00`8@V$`''P(`Z:#@0`@@Z$`
M)(/!`"B#X0`L."$`,$Z``"`](`&"@VG=""^;``!!GO_(B!P``"^```!!G@"(
M+X``/4&>`(!_A>-X2```"$&:`!2,!0`!+X```"\``#U`GO_P?[PH4(/[```O
MGP``0;[_B']^VWA_X_MX?X3C>'^EZWA(`8NM+X,``'Q_ZA1`G@`0?!_HKB^`
M`#U!G@`4A_X`!"^?``!`GO_02___3'P;\%`X8P`!?``6<)`:``!+__\\.Z``
M`$O__Z"4(?_0?`@"II/!`"@[P0`<D^$`+'Q_&WA_X_MX?\3S>).A`"0_H`&"
MD`$`-$S&,8)+__[-+X,``$&>`#R``0`<@3W="%0`$#I]($H4A`D`!"^```"0
M"?_\0)[_]'_C^WA_Q/-X3,8Q@DO__I4O@P``0)[_S(`!`#2#H0`D@\$`*'P(
M`Z:#X0`L."$`,$Z``""4(?_@?`@"ICB!`!R0`0`D3,8Q@DO__EF``0`D."$`
M('P(`Z9.@``@?`@"II0A_^"3X0`</^`!@I`!`"2`'X`$+X#__T&>`!R``0`D
M@'^`!(/A`!Q\"`.F."$`($Z``"`\8`&`.&-Y`$S&,8)+__^5+`,``$&"`!"(
M`P``+X```$">`"0X````D!^`!(`!`"2`?X`$@^$`''P(`Z8X(0`@3H``(&@`
M`#!\```T5`#9?F@```&0'X`$2___U'P(`J:4(?_P.&#__Y`!`!1(`8HY/&`!
M@#B````X8U.<2`&+28`!`!0X(0`0?`@#IDZ``"!\"`*FE"'_X#T@`8(\8`&`
MD^$`'#_@`8*3H0`4.&-[U)`!`"0X@```@4G<_#T@`8*("=ST@6H`$(%?W.14
M``9^56N$,($J``1]:P-XL6D``H%?W.2#J@`$2`&)W3T@`8*0?0`<@5_<Y(`)
MW00](`&"@6H`!)`+`"`X````@4G<W(%_W.0OB@``@2L`!$&>``B`"@!LD`D`
M)#@```"!/]SD@6D`!)`+`"B!/]SD@6D`!#T@`8*0"P`8@5_<Y(`)W0"!:@`$
MD`L`+(`!`"2#H0`4@^$`''P(`Z8X(0`@3H``()0A_W!\"`*FD\$`B'Q^&WF3
M`0!PDR$`=)-!`'B380!\DX$`@).A`(23X0",D`$`E$&"`!"('@``+X```$">
M`#2``0"4@P$`<(,A`'1\"`.F@T$`>(-A`'R#@0"`@Z$`A(/!`(B#X0",."$`
MD$Z``"!(`8DM?'P;>4&B_\@](`&`/6`!@#MI>0P](`&`.TMY$#LI>10[`0`0
M?X/C>$@!B:%_9-MX+`,``#OC``A_X_MX08(`K$@!B2$O@P``09[_W']$TWA_
MX_MX2`&)#2^#``!!GO_(?\/S>$@!B:5\?1MX?^/[>$@!B9E_O1H4.'T``D@!
MB35_),MX?'T;>'_%\WA_YOMX3,8Q@D@!B8U_H^MX?P3#>$@!B($O@___?Z/K
M>$&>`!2@`0`85``$)B^`0`!!G@!L2`&(07^CZWA(`8D)?X/C>$@!B/E_9-MX
M+`,``#OC``A_X_MX0(+_7'^#XWA(`8DE?\/S>$@!B$V``0"4@P$`<(,A`'1\
M"`.F@T$`>(-A`'R#@0"`@Z$`A(/!`(B#X0",."$`D$Z``"!+__YE2___F)0A
M_X!\"`*F.($`$)/A`'R0`0"$?'\;>$@!AT$O@P``0)X`(*`!`!A4"00F+XE`
M`$&>`"AM(/__+X"@`$&>`!R``0"$.&```(/A`'PX(0"`?`@#IDZ``"!_X_MX
M.(```D@!AXF``0"$?&,`-(/A`'Q48]E^?`@#IC@A`(!.@``@?`@"II0A_\"3
M00`HDZ$`-)/!`#A\?AMXD^$`/),A`"2380`LDX$`,)`!`$2(!```:!\`/2/_
M``!_Y`&4?^/[>$@!B!DX@0`<?'H;>'_#\WA,QC&"2__Z)7Q]&WE!@@%$2`&'
M^3\@`8)_FAA`0)T!`(@>``!_R?-X+X```$&>`?0O@``]0+X`#$@``>A!F@`4
MC`D``2^````O```]0)[_\'P>2%`X>@`"@Z$`''QC`A2#F=T(2`&'35>]$#HO
M@P``?'WA+D&>`7R)7@``/2`!@H`!`!R!:=T(+XH``%0`$#I]*P`NF4D``$&>
M`#`OB@`]09X`*#A^``%(```(09H`'(@#```X8P`!+X```"\``#V<"0`!0)[_
MZ#@``#V8"0``.2D``8@?```[_P`!+X```)@)```Y*0`!0)[_[(`!`$0X8```
M@R$`)(-!`"A\"`.F@V$`+(.!`#"#H0`T@\$`.(/A`#PX(0!`3H``((@?```[
M_P`!+X```)@=```[O0`!0;[_O(@?```[_P`!+X```)@=```[O0`!0)[_U$O_
M_Z`_(`&".X```(!YW0@X@``(@`,``"^```!!G@`@?&D;>(0)``0[G``!+X``
M`$">__17B1`Z.(D`"#T@`8*`">!D+X```$">`$@X```!?(,C>)`)X&1(`88-
M?'L;>4&"`$17G1`Z@)G="'^EZWA(`875DWG="($YW0@X````?3U*%)`)``23
M@0`<2__^2$@!A/57G1`Z+X,``)!YW0A`GO_8@`$`1#A@__^#(0`D@T$`*'P(
M`Z:#80`L@X$`,(.A`#2#P0`X@^$`/#@A`$!.@``@.````$O__C!\"`*FE"'_
ML#T@`8`XJ7APD\$`2)`!`%2`!0`$@,4`"'P>`WF!)0`,@64`$(%%`!2!!0`8
M@.4`')-A`#Q\>QMXDR$`-)-!`#B3@0!`DZ$`1)/A`$R0P0`8D2$`')%A`""1
M00`DD0$`*)#A`"R0`0`408(`T#T@`8"#10`@.REY'#N!`!A(```@?\/S>$S&
M,8)+__SY@]P``#N<``0OG@``09X`H'_#\WA,QC&"2__XZ7]DVWA\?QMY0:+_
MT(@?```O@```09[_Q']DVWA(`81E+X,``$">_\!_8]MX2`&%!7Q]&WA_0]-X
M2`&$^7^]&A1_X_MX2`&$[3N]``%\?1H42`&$B7\DRWA\?1MX?V7;>']&TWA_
MY_MX3,8Q@D@!A-U_P_-X?Z3K>$S&,8)+__Q=@]P``#N<``0OG@``0)[_:(`!
M`%2#(0`T@T$`.'P(`Z:#80`\@X$`0(.A`$2#P0!(@^$`3#@A`%!.@``@E"'_
MH'P(`J8\@`&`/2`!@CB$>'`XH``B.(0`))-A`$PX80`:.VG@,).!`%"3H0!4
MD\$`6)/A`%R0`0!D@!L``)`!`#PX````2`&#Y3Q@`8`X8WDD3,8Q@DO_]T$\
M8`&`.&-Y,$S&,8)+__<Q/&`!@#AC>3A,QC&"2__W(3Q@`8`X8WE$3,8Q@DO_
M]Q$](`&`.XEY3'^#XWA,QC&"2__V_3Q@`8`X8WE<3,8Q@DO_]NT](`&`.ZEY
M:'^CZWA,QC&"2__VV3T@`8`[R7D`?\/S>$S&,8)+__;%/2`!@#OI>71_X_MX
M3,8Q@DO_]K$\8`&`.&-Y@$S&,8)+__:A/&`!@#AC>8Q,QC&"2__VD3Q@`8`X
M8WF<3,8Q@DO_]H$\8`&`.&-YJ$S&,8)+__9Q/&`!@#AC>;1,QC&"2__V\7QD
M&WE!@@`0?^/[>$S&,8)+__K1/&`!@#AC><A,QC&"2__VS7QD&WE!@@`4/&`!
M@#AC>=Q,QC&"2__ZJ3Q@`8`X8WGH3,8Q@DO_]J5\9!MY08(`7'^CZWA,QC&"
M2__ZA3R``8!_@^-X.(1Z&$S&,8)+__IQ@`$`/($[``!\`$IY.2```$""`("`
M`0!D@V$`3(.!`%!\"`.F@Z$`5(/!`%B#X0!<."$`8$Z``"`\8`&`.&-Y^$S&
M,8)+__8U?&0;>4&"`!1_P_-X3,8Q@DO_^A5+__^0/(`!@#AA`"LXA'H,.*``
M"D@!@-TO@P``0+[_='_#\W@X@0`U3,8Q@DO_^>5+__]@2`&"%7P(`J:4(?_P
MD`$`%$@!@?5(`8&9.````"P#``!!@@`(@`,``'P#`WB``0`4."$`$'P(`Z9.
M@``@E"'_X'P(`J:3X0`<?'\;>9.A`!20`0`D08(`$(N_```OG0``0)X`*#Q@
M`8`X8WD,2`&`68`!`"2#H0`4@^$`''P(`Z8X(0`@3H``($@!@:T]0`&`?&/Z
M%#BC__]_GRA`0)P`1($J>'")8___B2D``'^+2`!`G@#8.`/__G^?`$!\'RA0
M?`D#ID"]`!1(``$$B`4``'^`6`!`G@"P.*7__T(`__!_A?@`0)X`,(!J>'"(
M`P``?X#H`$&^_W!(`7_-@`$`)(.A`!2#X0`<?`@#IC@A`"!.@``@.`7__X!J
M>'!_GP!`?!\H4'P)`Z9!G0"8+Y___T&>`)`XI?__0D``%(@%``")(P``?X!(
M`$&>_^Q\ORA0.&```#@%``(K@`0`0;W_%#^@`8)_Y/MX.[W@9#BE``$[O0`$
M?Z/K>$@!?ZU_H^MX2__^\'P+`W@X!?__?Y\`0'P?*%!\"0.F09T`0"^?__]`
MO@`,2```-(EE``!_B5@`0;[_,#BE__]"0/\H2___[#@```%\"0.F2___;#@`
M``%\"0.F2___!#@```%\"0.F2___S'P(`J:4(?_@D\$`&)`!`"23X0`<?'\;
M>$O__D%+_\@U?'X;>$O_]`DO@P``09X`&"^?``!!G@`0B!\``"^```!`G@`<
M@`$`)(/!`!B#X0`<?`@#IC@A`"!.@``@/(`!@'_#\W@XA'H<2`%_.7^>&`!`
MGO_4@`$`)'_C^WB#P0`8?`@#IH/A`!PX(0`@2__U2)0A_]!\"`*FD&$`'#AA
M`!R0@0`8.($`&)"A`!0XH0`4D^$`+)/!`"B0`0`T2`%^E3T@`8*+Z=S@+Y\`
M`$&>`8R`80`</2!#,)$A``@](`&`.`,`!<`)>.B0`0`,/2`!@#U@`8+)H0`(
MB`O<X?VM`"C("7CP/2`!@&````.8"]SA_:T`*L@)>/C_C0``09T!E%1C$#HX
M8P`42`%_63T@`8*`H0`<.^G@9)!_!`@](`&`@4$`&"^%``$Y*7HD/6`!@H`*
M```Y:X`$D2,`!#T@`8"0`P``.6L`!#DI>B@X```$D6,`"'QF&WB1(P`,.0/_
M_)`?!`Q`G0`D.`7__SE@``1\"0.F?`I8+GTF6A0Y:P`$D`D`#$(`__`Y)0`$
M.````%4I$#J`?P0$/(`!@'P)02XXA'58.*4``SC@``!(`7U5?'X;>4&"`*B`
M?P0$2`%]Y3Q@`8`X8WE<3,8Q@DO_\ADO@P``09X`+(!_!`1(`7Z-2`%^<8`!
M`#1_P_-X@^$`+(/!`"A\"`.F."$`,$Z``""`?P00+X,``$&>`&1+__W5@'\$
M!$@!?E5(`7XY@`$`-'_#\WB#X0`L@\$`*'P(`Z8X(0`P3H``($@!?:D](`&"
M+X,``)!IY&A!G@!@2`%\E3T@`8*;Z=S42__^6(!_!`1(`7T!?'X;>$O__U`\
M8`&`.&-Y:$S&,8)+__%M+X,``)!_!!!!OO]42__]64O__X0\8`&`/(`!@CAC
M>I@XA.!03,8Q@D@!>^TX8``!2`%]'90A^T!\"`*F?8``)CT@`8*3H02T?'T;
M>#Q@`8"2H024.&-Y:#JIX#"3002HDX$$L)/!!+B3X02\?)\C>)`!!,2`%0``
MD`$$?#@```"1@02,DH$$D)+!!)B2X02<DP$$H),A!*23802L3,8Q@DO_\,D]
M(`&`?'H;>(/)>'!_H^MX.XEX<'_$\WA(`7Q)+X,``$&>`'@\8`&`?Z3K>#AC
M>8Q,QC&"2__TA8`!!'R!-0``?`!*>3D@``!_H^MX0((!G(`!!,2!@02,@H$$
MD'P(`Z:"H024?8"!((+!!)B"X02<@P$$H(,A!*2#002H@V$$K(.!!+"#H02T
M@\$$N(/A!+PX(03`3H``('^CZWA(`7QU@WP`('QY&WA_X_MX?V3;>$@!>VE\
M?QMY0:+_;#T@`8`[````.HEY#"X:```](`&`.SD``3KI>1QC&(``.X$`?#K!
M`!B('P``+X```$">``A^GZ-X09(`&']#TWA_Y/MX2`%[:2^#``!!G@"0?^/[
M>$@!?`&)/@``?7\:%(@+__]_@$@`0)X`)#@```")*__^F`O__SAC__\Y:___
MB!X``'^`2`!!GO_D?!D:%"^``_]!O?[4?^7[>'_&\WA_I^MX?N2[>'^#XWA,
MQC&"2`%[O7^#XWA^Q+-X2`%ZL2^#``!`G@`4H`$`(%0`!"9_@,``09X`(#A@
M``!_9-MX2`%Z?2^#``!\?QMX0)[_/$O__GA_@^-X.(```4@!>FDO@P``0)[_
MU#Q@`8!_A.-X.&-YC$S&,8)+__+E?X/C>$@!><5\?1MX2__^5$@!>PD\`/__
M?"P+>&``?B!\(0%N?`@"II/,__@_P`&`DRS_Y#D^>'"33/_H@4D`3#UA``&!
M"0!0@.D`5(#)`%B`J0!<@(D`8)-L_^R3C/_PDZS_])/L__P_X`&"@ZD`9#O_
MX#"0#``$@RD`=(`)`$B#B0!H@VD`;(-)`'`](`&`DPS_X#L!@9"2S/_8?'8;
M>)',_[B1[/^\D@S_P)(L_\223/_(DFS_S)*,_]"2K/_4DNS_W(!I>.R!/P``
MD2N!C#D@``"3N'\8D!A_+)%8?S"1&'\TD/A_")#8?PR0N'\0D)A_%).8?QR3
M>'\@DUA_)),X?RA,QC&"2__MY7Q]&WE!@@`0B!T``"^```!`G@)<2__WZ7QZ
M&WE_H``F08("J(DZ```OB0``09X`3']*TW@]``&"/.`!@D&<`"B`"-SH?XD`
M`$"<`!R!9]SP52D0.GTI6A2`"0`T<`0%`$""``PX``!?F`H``(TJ``$OB0``
M0)[_R(!X?P@O@P``09X!A#NX?PQ(```4@'T``#N]``0O@P``09X!;$S&,8)+
M_^U!?'P;>4&B_^2('```+X```$&>_]A+__"=+X,``$&>_\Q_@^-X2`%W]7Q[
M&WE!H@$X?V/;>$@!>55\?1MX?T/3>$@!>4E_O1H4.YT$!'^#XWA(`7CA@]YX
M<#R``8`\X`&`?'\;>#B$>C1_9=MX..=Z''](TWA_QO-XD\$`+$S&,8)(`7DA
M?^/[>#B``<!(`7B=+X/__T&>`4A_X_MX.)A^J$@!=VDO@P``0)X`%*`8?K!4
M``0F+X!``$&>`<0](`&"@+8``(!IW/@\@`&`.(1ZR'_F^WA,QC&"2`%W&3O`
M```\P`&"/($``3C&X#!_P_-X@02!C("&``!]"")Y.(```$""`O"!80``@`L`
M!('+_[B!Z_^\?`@#IH(+_\""*__$@DO_R()K_\R"B__0@JO_U(++_]B"Z__<
M@PO_X(,K_^2#2__H@VO_[(.+__"#J__T@\O_^(/K__Q]85MX3H``(#M@``"#
MN'\L+YT``$&^_L2('0``.YA_,"^```!`O@`L2__^L"^;``!`OOZH@[P``"^=
M``!!OOZ<B!T``#N<``0O@```0;[^C'^CZWA+_^\%+X,``$&>_]!_H^MX2`%V
M77Q[&WA+___`2__QX7^CZWA(`79)?'X;>$O__PA(`7;M@`,``"^``!%!GOZP
M/2`!@H.6``"#J=SX2`%VT8#C```\@`&`?Z/K>#B$>D!_A>-X?^;[>$S&,8)(
M`779.\```$O__L`[@```.WA_($@``!A7O2`^?Z`1(%>]X#X[G``$0+[]0'Q\
MV"XO@P``09X!F$S&,8)+_^KI?&D;>4&B_]2("0``+X```$&>_\A(`76M?'H;
M>7^@`"9+__^X@[A^M$@!=ME_G1@`0)[^-*`8?K!4``7^+X`!P$">_B1_@^-X
M2`%VD7Q^&W@\8`&`.&-\:$S&,8)+_^J)+X,``$&>`3B#M@``2`%U57QD&WA_
MH^MX2__Y.7Q[&WE!@@$<?V/;>$@!=JDO@P`#?'T;>$&=`\Q+_^IU+X,``$">
M`!Q_8]MX.(```$S&,8)(`78!?'D;>4""`.P\@`&`/&`!@#B$>A@X8WD`3,8Q
M@DO_[@D[H```2`%V23T@`8`[B7O4/(`!@(#!`"Q\9QMX.(1ZI'_#\WA_Y?MX
M?XCC>$S&,8)(`79%/2`!@#MI>K1(``!`2`%U78`#```O@``10)X`1$@!=?T[
MO0`!@,$`+'QG&WA_9-MX?\/S>'_E^WA_J.MX?XGC>$S&,8)(`77]?\/S>#B`
M`<!(`75Y+X/__T&>_[1_X_MX2`%UD3R``8"`9'CL?\3S>$S&,8)+_^U=?\/S
M>$O_[\U+__T`/2`!@#M)>BQ+__OH2`%U>8-V``!+__[D.*#__SC`_^XXX``"
M.[A_.$@!=,5_(\MX?Z3K>#B@``9(`75]B!A_."^```!`G@`0B!A_.2^``$-!
MG@9X.,```'\CRW@XH```..```$@!=(D]0&=%.2```&%*(P&1(0`0/8#OS9%!
M`!0\P0`!.6```&&,JXG(`0`0/4"8NCD@``!A2MS^V`:`R#N```"180`0.6``
M`)&!`!0]@!`R88Q4=CN@``#(`0`0.````&``@,@X@```V`:`T']!`A21(0`0
M.2```)%!`!0]0,/284KA\#@```#(`0`08(2!`#L8?SA^X2(4V`:`V)%A`!`Y
M8```D8$`%#F```#(`0`0V`:`X)$A`!"100`4R`$`$-@&@.B180`0D8$`%,@!
M`!#8!H#PDX$`$).A`!3(`0`0D`:!0-@&@/@XH```?R/+>&"E@`!_!,-X2`%T
M67Q[&WE`@0'H/($``3C```"#A(#P5V`??H.D@/1_9/YP?YPP0%2)&#A\"4MX
M5VH8.'V*Z!1]:>$4?V7;>'V'8WA`G0#(/0$``8.(@/B#J(#\,[T``7^<`923
M@0`0DZ$`%,@!`!#8"(#X/4$``52`&#B!"H%`5*H??I#!`!!4B1]^D.$`%'P*
M4WA]G5`4?7Q)%#R!``'(`0`0+X@``'\=PWA^_+MXV`2`\)%A`!"1@0`4R`$`
M$-@$@/A`G@!H+YL`/T"=`"Q_I.MX.*``0'^#XW@[>__`2`%S*7]#TWA+_[O)
M+YL`/SN]`$!!G?_<?Z3K>'^#XWA_9=MX2`%S!3R!``&39(%`2__^Z'^<,`!!
MG@0L/0$``8.(@/B#J(#\2___3"`(`$!_?=MX?YL``$"=``A\'0-X?P3#>'QW
M0A1_I>MX?OR[>$@!<KD\@0`!@`2!0'P=`A0O@`!`D`2!0$">_I!_0]-X?WW8
M4'^XZA1+_[LY2___3'^;&A0\@`&`.(1Z?#A\__Q(`7(9+X,``$"^_"`OG0`$
M09X`&("!`"R('/_[B20``'^`2`!`GOP$@Y8`!"^<``!!OOOX?X/C>$@!<HDK
M@P`#0)W[Z'Q\&A0\@`&`.&/__#B$>H1(`7'%+X,``$"^^\Q_F^-X2__[Q'\C
MRWA(`7&]/($``8,$@/"#)(#T5P#H!(+$@/A7*NC^@N2`_'P*4W@X`/^`54,&
MOCEC``%](](4+XL`.)@)`#A`G0,D(*L`0#B````X:0`Y2`%Q,7]#TWA+_[IA
M.````&``@0`X@```?&$"%#B@`#A(`7$15L!`+E;[1CY\&]MX5LF`'E;]A#Y6
MP,`.5N;"/GT]ZWA\!C-X5PE`+E<`@!Y7*$8^5P3`#E<LA#Y7*L(^?2A#>'P,
M8WA\BE-X/($``7]#TWB;9($XFZ2!.9C$@3J:Y($[F02!/)F$@3V91($^FR2!
M/TO_N=4\@0`!/0$``8"$@,B!"(#,5(!`+E2+1CY5"$8^D6$`('P*0WA4B8`>
MD4$`)#R!``$]`0`!/4$``8"$@,P]80`!5(2$/GTF(W@](0`!D,$`'#S!``&!
M"(#(50B$/I$!`!B!2H#0@,:`U($I@,B!:X#,5-%&/E4@P`Y524`N?3&+>%39
MPCY52<`.57/"/GTYRW@]80`!/2$``8%K@-R!*8#8?!.;>%3/A#Y50(`>?`][
M>'TJ2WA5($`N57=&/GP7NW@\P0`!54#`#CU!``&!2H#@52F`'H#&@.15=80^
M?36K>%5]PCY524`N5-M&/GP=ZWA].]MX54"`'E5)P`X]00`!5,2$/H%*@.A4
MQL(^?`0C>'TF,WA50$`N54F`'CU!``$]80`!@4J`[(%K@.A52$8^/4$``8%*
M@.Q\"$-X56#`#E5,A#Y]+&-X/2$``8$I@.Q5*<(^?`I+>#TA``&100`,/4$`
M`8@!`">!*8#H52G"/I$A``B8"H%XB`J`SXDA`!^8"H%[F2J!>9IJ@7J:*H%\
MF>J!?9LJ@7Z)*H#7F(J!A8@*@-^(BH#GF2J!?SD@``";JH&"82F!3YMJ@81_
M04H4F0J!B#T@`8":ZH&`.REZG)JJ@8%_7--XF`J!@SN@``"8RH&&F(J!AYF*
M@8F)"H#OB,$`#YD*@8N8RH&*.4```&%*@7A_85(4?+W8KG^#XWA_),MX.YP`
M`DS&,8)(`6]M+YT`$SN]``%`GO_@.````#TA``&`P0`L/(`!@#T``8"8"8%W
M.(1ZC']'TW@Y"'O4?\/S>'_E^WA,QC&"2`%O+4O_^41_G6!`0;W["#TA``&#
MB8#X@ZF`_$O_^QQ\8](4(*L`.#B````X8P`Y2`%N#4O__/R(&'\Z+X``04">
M^82(&'\[+X``0T">^7B(&'\\+X``2$">^6R(&'\]+X``14">^6`XP/_&..``
M`CB@__]_(\MX2`%MY7^DZWA_(\MX.*``*4@!;IT\@`&`@,$`+#T``8`XA'J,
M?Z?K>#D(>]1_P_-X?^7[>$S&,8)(`6Y]2__XE)0A]]!\"`*F/2`!@I/!""@[
MR>`PD^$(+#OA!!N0`0@T@!X``)`!"!PX````DX$(().A""1(`6X9/(`!@#S`
M`8!\91MX.(1['#C&>RA_X_MX3,8Q@D@!;B$O@P``0)P`0#O@``"``0@<@3X`
M`'P`2GDY(```?^/[>$""`&R``0@T@X$(((.A""1\"`.F@\$(*(/A""PX(0@P
M3H``(#N!`!I_X_MX?X3C>#B@!`!(`6W9?'T;>4&`_ZPX?0`!2`%M27Q@&WE!
MHO^<?X3C>'^EZWA\'P-X2`%M03@```!\'^FN2___A$@!;5F4(?_P."$`$$O_
M_Q!\"`*FE"'_T#Q@`8"300`8.&-Y3)`!`#0_0`&".````9-A`!R3@0`@DZ$`
M))/!`"B3X0`LF!K<[$S&,8)+_^#A+`,``$&"`!"(`P``+X``,4&>`=Q+_^BA
M/&`!@#AC>S`X@``!.*``"T@!;)$L`P``08(!Y#T@`8([H```.VG@9($C`!"`
M&P0,@XD`&"^```%`G0"(.\```4@``"R`@P`0?^/[>$@!;!TO@P``0)X`;(`;
M!`P[W@`!.[T``7^`\`!`G0!8?X/C>'^DZW@XH```2`%LD2P#``!!@@!`@&,`
M`%?)$#J!>P0(@`,`"'_I6"YP"@0`0(+_J#B````XH``"2`%JV7QD&WA_X_MX
M2`%KM2^#``!!GO^<@3L$##@)__]_@.@`09X!/#Q@`8`X@``!.&-[.#B@``1(
M`6O!?'\;>4&"`"R!/P`0/(`!@#B$>SR`:0``2`%J]8$_`!"`:0``@`,`"'0)
M`$!`@@$@/&`!@#B```$X8WM$.*``!$@!:WU\?AMY08(`+#Q@`8`X8WF,3,8Q
M@DO_WXDL`P``08(!&($^`!!\9!MX@&D``$@!:IT\8`&`.````#E@```](`&"
M.&-Y:)@:W.R1:=S83,8Q@DO_WTTO@P``?W_;>)!_!!!!G@"P.(`!P$@!:R%\
M9AMY08(`%"^&`!%!G@`,+X;__T">`-R``0`T@T$`&(-A`!Q\"`.F@X$`((.A
M`"2#P0`H@^$`+#@A`#!.@``@B`,``2^```!`OOX@/&`!@#B```$X8WLP.*``
M"T@!:K$L`P``0(+^)#T@`8([:>!D2__^S"^)``%`O?[$.^```7^#XW@[_P`!
M2`%IC8`;!`Q_@/@`09W_[$O__J1(`6F!2__^X(![!`A+_^^Q+X,``)![!!!`
MG@!P/&`!@#AC>TA,QC&"2`%I&4O__4%\?QMY08(`/($^`!!_Y/MX@&D``$@!
M:7U_X_MX2`%J74O__MB!.P0(/&`!@("[!!`X8WN4@(D``$S&,8)(`6C5@3X`
M$(%[!`B`:0``@(L``$@!:4%+__ZD@3X`$(!I``"``P`(<`D$`$&"`$R`8P`0
M@)L$"$@!:+6!/@`0?'\;>(%[!`B`:0``@\L``(`#``AP"00`08(`,("C`!`\
M8`&`?\3S>#AC>VQ_YOMX3,8Q@D@!:&$X@```.*```D@!:&5+__^P.*```CB`
M``!(`6A5?&4;>$O__\A\"`*FE"'_\#Q@`8`\@`&"/*`!@#AC>]@XA-Y8.*5[
M])`!`!1(`6B=@`$`%#@A`!!\"`.F3H``('P(`J:4(?_PD`$`%$O__[T\H`&`
M/&`!@#BE>]0\@`&`.&-\`#B$<9!\IBMX..```$@!:!F``0`4."$`$'P(`Z9.
M@``@V<O_<-GK_WC:"_^`VBO_B-I+_Y#::_^8VHO_H-JK_ZC:R_^PVNO_N-L+
M_\#;*__(VTO_T-MK_]C;B__@VZO_Z-O+__#;Z__X3H``()'+_[B1Z_^\D@O_
MP)(K_\222__(DFO_S)*+_]"2J__4DLO_V)+K_]R3"__@DRO_Y)-+_^B3:__L
MDXO_\).K__23R__XD^O__$Z``"#)R_]PR>O_>,H+_X#**_^(RDO_D,IK_YC*
MB_^@RJO_J,K+_[#*Z_^XRPO_P,LK_\C+2__0RVO_V,N+_^#+J__HR\O_\,OK
M__A.@``@@<O_N('K_[R""__`@BO_Q()+_\B":__,@HO_T(*K_]2"R__8@NO_
MW(,+_^"#*__D@TO_Z(-K_^R#B__P@ZO_](/+__B#Z__\3H``(,G+_W#)Z_]X
MR@O_@,HK_XC*2_^0RFO_F,J+_Z#*J_^HRLO_L,KK_[C+"__`RRO_R,M+_]#+
M:__8RXO_X,NK_^C+R__P@`L`!,OK__A\"`.F?6%;>$Z``""!R_^X@>O_O((+
M_\""*__$@DO_R()K_\R"B__0@JO_U(++_]B"Z__<@PO_X(,K_^2#2__H@VO_
M[(.+__"#J__T@\O_^(`+``2#Z__\?`@#IGUA6WA.@``@?`@"II0A__`](`&"
M.2G<K)/A``R0`0`4.^G__(`)__PO@/__09X`&'P)`Z9.@`0AA!___"^`__]`
MGO_P@`$`%(/A``PX(0`0?`@#IDZ``"!\"`*FE"'_\)`!`!2``0`4."$`$'P(
M`Z9.@``@E"'_\'P(`J:3X0`,D`$`%'P_"WA+_ZX%@6$``(`+``1\"`.F@^O_
M_'UA6WA.@``@)$9R965"4T0Z('-R8R]L:6(O8W-U+W!O=V5R<&,O8W)T:2Y3
M+'8@,2XR+C(X+C$N-"XQ(#(P,3`O,#8O,30@,#(Z,#DZ,#8@:V5N<VUI=&@@
M17AP("0```&`?$`!@'Q(`8!\6`&`?&`!@'QH`8!\<`&`?(0``````8!\1%]?
M14Y67U!!4E]#3$5!3E]?("`@("`@("`@("`@("`@``````&`?#@!@'D,````
M``&`>=P!@'G@`8!\+`&`>6P!@'PT``````&`?!@!@'P@`````%F````!@'EH
M``````````!!S____X```%!!4E]#3$5!3@```"X````N+@``)7,O)7,````E
M<R5S)7,``%!%4DPU3$E"`````%!%4DQ,24(`4$523#5/4%0`````4$523$E/
M``!005)?24Y)5$E!3$E:140`4$%27U-005=.140`4$%27U1%35``````4$%2
M7T1%0E5'````4$%27T-!0TA%````4$%27U!23T=.04U%`````%!!4E]!4D=#
M`````%!!4E]!4D=67S```%!!4E]'3$]"04Q?1$5"54<`````4$%27T=,3T)!
M3%]435!$25(```!005)?5$U01$E2``!005)?1TQ/0D%,7U1%35``4$%27T=,
M3T)!3%]#3$5!3@````!005)?0TQ%04X]```Q````<&%R+0`````M90``+2T`
M`%-94U1%30``)7,E<R5S)7,`````)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@
M<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R;F\])6DI"@``<&%R;``````N
M<&%R`````"5S)7-C86-H92TE<R5S```E,#)X`````"5S)7-T96UP+25U)7,`
M```E<R5S=&5M<"TE=2TE=25S`````"5S.B!P<FEV871E('-U8F1I<F5C=&]R
M>2`E<R!I<R!U;G-A9F4@*'!L96%S92!R96UO=F4@:70@86YD(')E=')Y('EO
M=7(@;W!E<F%T:6]N*0H``"]P<F]C+R5I+R5S`&9I;&4`````05)'5@`````8
M````<&5R;``````P````56YA8FQE('1O(&-R96%T92!C86-H92!D:7)E8W1O
M<GD`````)7,Z(&5X96-U=&EO;B!O9B`E<R!F86EL960@*&5R<FYO/25I*0H`
M`"5S.B!C<F5A=&EO;B!O9B!P<FEV871E(&-A8VAE('-U8F1I<F5C=&]R>2`E
M<R!F86EL960@*&5R<FYO/25I*0H`````1'EN84QO861E<CHZ8F]O=%]$>6YA
M3&]A9&5R`'!E<FQX<VDN8P```$EN=&5R;F%L<SHZ4$%2.CI"3T]4`````%53
M15(`````55-%4DY!344`````5$5-4$1)4@!435``+W9A<B]T;7`O````.@``
M`$Q$7TQ)0E)!4EE?4$%42`!,24)0051(`$Q)0E)!4EE?4$%42`````!$64Q$
M7TQ)0E)!4EE?4$%42````%-(3$E"7U!!5$@`)$9R965"4T0Z('-R8R]L:6(O
M8W-U+W!O=V5R<&,O8W)T;BY3+'8@,2XR+C(X+C$N-"XQ(#(P,3`O,#8O,30@
M,#(Z,#DZ,#8@:V5N<VUI=&@@17AP("0`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````!@=RT_____R,A+W5S<B]B:6XO<&5R;`IE=F%L("=E>&5C("]U
M<W(O8FEN+W!E<FP@("U3("0P("1[,2LB)$`B?2<*("`@(&EF(#`[(",@;F]T
M(')U;FYI;F<@=6YD97(@<V]M92!S:&5L;`H*<&%C:V%G92!?7W!A<E]P;#L*
M"B,@+2TM(%1H:7,@<V-R:7!T(&UU<W0@;F]T('5S92!A;GD@;6]D=6QE<R!A
M="!C;VUP:6QE('1I;64@+2TM"B,@=7-E('-T<FEC=#L*"B-L:6YE(#$U.`H*
M;7D@*"1P87)?=&5M<"P@)'!R;V=N86UE+"!`=&UP9FEL92D["D5.1"![(&EF
M("@D14Y6>U!!4E]#3$5!3GTI('L*("`@(')E<75I<F4@1FEL93HZ5&5M<#L*
M("`@(')E<75I<F4@1FEL93HZ0F%S96YA;64["B`@("!R97%U:7)E($9I;&4Z
M.E-P96,["B`@("!M>2`D=&]P9&ER(#T@1FEL93HZ0F%S96YA;64Z.F1I<FYA
M;64H)'!A<E]T96UP*3L*("`@(&]U=',H<7%[4F5M;W9I;F<@9FEL97,@:6X@
M(B1P87)?=&5M<")]*3L*("`@($9I;&4Z.D9I;F0Z.F9I;F1D97!T:"AS=6(@
M>R`H("UD("D@/R!R;61I<B`Z('5N;&EN:R!]+"`D<&%R7W1E;7`I.PH@("`@
M<FUD:7(@)'!A<E]T96UP.PH@("`@(R!$;VXG="!R96UO=F4@=&]P9&ER(&)E
M8V%U<V4@=&AI<R!C875S97,@82!R86-E('=I=&@@;W1H97(@87!P<PH@("`@
M(R!T:&%T(&%R92!T<GEI;F<@=&\@<W1A<G0N"@H@("`@:68@*"UD("1P87)?
M=&5M<"`F)B`D7D\@;F4@)TU35VEN,S(G*2!["B`@("`@("`@(R!3;VUE=&AI
M;F<@=V5N="!W<F]N9R!U;FQI;FMI;F<@=&AE('1E;7!O<F%R>2!D:7)E8W1O
M<GDN("!4:&ES"B`@("`@("`@(R!T>7!I8V%L;'D@:&%P<&5N<R!O;B!P;&%T
M9F]R;7,@=&AA="!D:7-A;&QO=R!U;FQI;FMI;F<@<VAA<F5D"B`@("`@("`@
M(R!L:6)R87)I97,@86YD(&5X96-U=&%B;&5S('1H870@87)E(&EN('5S92X@
M56YL:6YK('=I=&@@82!B86-K9W)O=6YD"B`@("`@("`@(R!S:&5L;"!C;VUM
M86YD('-O('1H92!F:6QE<R!A<F4@;F\@;&]N9V5R(&EN('5S92!B>2!T:&ES
M('!R;V-E<W,N"B`@("`@("`@(R!$;VXG="!D;R!A;GET:&EN9R!O;B!7:6YD
M;W=S(&)E8V%U<V4@;W5R('!A<F5N="!P<F]C97-S('=I;&P*("`@("`@("`C
M('1A:V4@8V%R92!O9B!C;&5A;FEN9R!T:&EN9W,@=7`N"@H@("`@("`@(&UY
M("1T;7`@/2!N97<@1FEL93HZ5&5M<"@*("`@("`@("`@("`@5$5-4$Q!5$4@
M/3X@)W1M<%A86%A8)RP*("`@("`@("`@("`@1$E2(#T^($9I;&4Z.D)A<V5N
M86UE.CID:7)N86UE*"1T;W!D:7(I+`H@("`@("`@("`@("!3549&25@@/3X@
M)RYC;60G+`H@("`@("`@("`@("!53DQ)3DL@/3X@,"P*("`@("`@("`I.PH*
M("`@("`@("!P<FEN="`D=&UP("(C(2]B:6XO<V@*>#TQ.R!W:&EL92!;(%PD
M>"`M;'0@,3`@73L@9&\*("`@<FT@+7)F("<D<&%R7W1E;7`G"B`@(&EF(%L@
M7"$@+60@)R1P87)?=&5M<"<@73L@=&AE;@H@("`@("`@8G)E86L*("`@9FD*
M("`@<VQE97`@,0H@("!X/6!E>'!R(%PD>"`K(#%@"F1O;F4*<FT@)R(@+B`D
M=&UP+3YF:6QE;F%M92`N("(G"B(["B`@("`@("`@("`@(&-H;6]D(#`W,#`L
M)'1M<"T^9FEL96YA;64["B`@("`@("`@;7D@)&-M9"`]("1T;7`M/F9I;&5N
M86UE("X@)R`^+V1E=B]N=6QL(#(^)C$@)B<["B`@("`@("`@8VQO<V4@)'1M
M<#L*("`@("`@("!S>7-T96TH)&-M9"D["B`@("`@("`@;W5T<RAQ<2A3<&%W
M;F5D(&)A8VMG<F]U;F0@<')O8V5S<R!T;R!P97)F;W)M(&-L96%N=7`Z("D*
M("`@("`@("`@("`@("X@)'1M<"T^9FEL96YA;64I.PH@("`@?0I]('T*"D)%
M1TE.('L*("`@($EN=&5R;F%L<SHZ4$%2.CI"3T]4*"D@:68@9&5F:6YE9"`F
M26YT97)N86QS.CI005(Z.D)/3U0["@H@("`@979A;"!["@I?<&%R7VEN:71?
M96YV*"D["@II9B`H97AI<W1S("1%3E9[4$%27T%21U9?,'T@86YD("1%3E9[
M4$%27T%21U9?,'T@*2!["B`@("!`05)'5B`](&UA<"`D14Y6>R)005)?05)'
M5E\D7R)]+"`H,2`N+B`D14Y6>U!!4E]!4D=#?2`M(#$I.PH@("`@)#`@/2`D
M14Y6>U!!4E]!4D=67S!].PI]"F5L<V4@>PH@("`@9F]R("AK97ES("5%3E8I
M('L*("`@("`@("!D96QE=&4@)$5.5GLD7WT@:68@+UY005)?05)'5E\O.PH@
M("`@?0I]"@IM>2`D<75I970@/2`A)$5.5GM005)?1$5"54=].PH*(R!F:7@@
M)'!R;V=N86UE(&EF(&EN=F]K960@9G)O;2!0051("FUY("5#;VYF:6<@/2`H
M"B`@("!P871H7W-E<"`@("`]/B`H)%Y/(#U^("]>35-7:6XO(#\@)SLG(#H@
M)SHG*2P*("`@(%]E>&4@("`@("`@(#T^("@D7D\@/7X@+UXH/SI-4U=I;GQ/
M4S)\8WEG=VEN*2\@/R`G+F5X92<@.B`G)RDL"B`@("!?9&5L:6T@("`@("`]
M/B`H)%Y/(#U^("]>35-7:6Y\3U,R+R`_("=<7"<@.B`G+R<I+`HI.PH*7W-E
M=%]P<F]G;F%M92@I.PI?<V5T7W!A<E]T96UP*"D["@HC($UA9VEC('-T<FEN
M9R!C:&5C:VEN9R!A;F0@97AT<F%C=&EN9R!B=6YD;&5D(&UO9'5L97,@>WM[
M"FUY("@D<W1A<G1?<&]S+"`D9&%T85]P;W,I.PI["B`@("!L;V-A;"`D4TE'
M>U]?5T%23E]??2`]('-U8B![?3L*"B`@("`C($-H96-K(&9I;&4@='EP92P@
M9V5T('-T87)T(&]F(&1A=&$@<V5C=&EO;B![>WL*("`@(&]P96X@7T9(+"`G
M/"<L("1P<F]G;F%M92!O<B!L87-T.PH@("`@8FEN;6]D92A?1D@I.PH*("`@
M(&UY("1B=68["B`@("!S965K(%]&2"P@+3@L(#(["B`@("!R96%D(%]&2"P@
M)&)U9BP@.#L*("`@(&QA<W0@=6YL97-S("1B=68@97$@(EQN4$%2+G!M7&XB
M.PH*("`@('-E96L@7T9(+"`M,3(L(#(["B`@("!R96%D(%]&2"P@)&)U9BP@
M-#L*("`@('-E96L@7T9(+"`M,3(@+2!U;G!A8VLH(DXB+"`D8G5F*2P@,CL*
M("`@(')E860@7T9(+"`D8G5F+"`T.PH*("`@("1D871A7W!O<R`]("AT96QL
M(%]&2"D@+2`T.PH@("`@(R!]?7T*"B`@("`C($5X=')A8W1I;F<@96%C:"!F
M:6QE(&EN=&\@;65M;W)Y('M[>PH@("`@;7D@)7)E<75I<F5?;&ES=#L*("`@
M('=H:6QE("@D8G5F(&5Q(")&24Q%(BD@>PH@("`@("`@(')E860@7T9(+"`D
M8G5F+"`T.PH@("`@("`@(')E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D
M8G5F*3L*"B`@("`@("`@;7D@)&9U;&QN86UE(#T@)&)U9CL*("`@("`@("!O
M=71S*'%Q*%5N<&%C:VEN9R!F:6QE("(D9G5L;&YA;64B+BXN*2D["B`@("`@
M("`@;7D@)&-R8R`]("@@)&9U;&QN86UE(#U^('-\7BA;82UF7&1=>SA]*2]\
M?"`I(#\@)#$@.B!U;F1E9CL*("`@("`@("!M>2`H)&)A<V5N86UE+"`D97AT
M*2`]("@D8G5F(#U^(&U\*#\Z+BHO*3\H+BHI*%PN+BHI?"D["@H@("`@("`@
M(')E860@7T9(+"`D8G5F+"`T.PH@("`@("`@(')E860@7T9(+"`D8G5F+"!U
M;G!A8VLH(DXB+"`D8G5F*3L*"B`@("`@("`@:68@*&1E9FEN960H)&5X="D@
M86YD("1E>'0@(7X@+UPN*#\Z<&U\<&Q\:7A\86PI)"]I*2!["B`@("`@("`@
M("`@(&UY("@D;W5T+"`D9FEL96YA;64I(#T@7W1E;7!F:6QE*"1E>'0L("1C
M<F,I.PH@("`@("`@("`@("!I9B`H)&]U="D@>PH@("`@("`@("`@("`@("`@
M8FEN;6]D92@D;W5T*3L*("`@("`@("`@("`@("`@('!R:6YT("1O=70@)&)U
M9CL*("`@("`@("`@("`@("`@(&-L;W-E("1O=70["B`@("`@("`@("`@("`@
M("!C:&UO9"`P-S4U+"`D9FEL96YA;64["B`@("`@("`@("`@('T*("`@("`@
M("`@("`@)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9G5L;&YA;65](#T@)&9I
M;&5N86UE.PH@("`@("`@("`@("`D4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F
M:6QE;F%M97T@/2`D9G5L;&YA;64["B`@("`@("`@?0H@("`@("`@(&5L<VEF
M("@@)&9U;&QN86UE(#U^(&U\7B\_<VAL:6(O?"!A;F0@9&5F:6YE9"`D14Y6
M>U!!4E]414U0?2`I('L*("`@("`@("`@("`@(R!S:&]U;&0@8F4@;6]V960@
M=&\@7W1E;7!F:6QE*"D*("`@("`@("`@("`@;7D@)&9I;&5N86UE(#T@(B1%
M3E9[4$%27U1%35!]+R1B87-E;F%M921E>'0B.PH@("`@("`@("`@("!O=71S
M*")32$Q)0CH@)&9I;&5N86UE7&XB*3L*("`@("`@("`@("`@;W!E;B!M>2`D
M;W5T+"`G/B<L("1F:6QE;F%M92!O<B!D:64@)"$["B`@("`@("`@("`@(&)I
M;FUO9&4H)&]U="D["B`@("`@("`@("`@('!R:6YT("1O=70@)&)U9CL*("`@
M("`@("`@("`@8VQO<V4@)&]U=#L*("`@("`@("!]"B`@("`@("`@96QS92![
M"B`@("`@("`@("`@("1R97%U:7)E7VQI<W1[)&9U;&QN86UE?2`]"B`@("`@
M("`@("`@("1005(Z.DAE879Y.CI-;V1U;&5#86-H97LD9G5L;&YA;65](#T@
M>PH@("`@("`@("`@("`@("`@8G5F(#T^("1B=68L"B`@("`@("`@("`@("`@
M("!C<F,@/3X@)&-R8RP*("`@("`@("`@("`@("`@(&YA;64@/3X@)&9U;&QN
M86UE+`H@("`@("`@("`@("!].PH@("`@("`@('T*("`@("`@("!R96%D(%]&
M2"P@)&)U9BP@-#L*("`@('T*("`@(",@?7U]"@H@("`@;&]C86P@0$E.0R`]
M("AS=6(@>PH@("`@("`@(&UY("@D<V5L9BP@)&UO9'5L92D@/2!`7SL*"B`@
M("`@("`@<F5T=7)N(&EF(')E9B`D;6]D=6QE(&]R("$D;6]D=6QE.PH*("`@
M("`@("!M>2`D9FEL96YA;64@/2!D96QE=&4@)')E<75I<F5?;&ES='LD;6]D
M=6QE?2!\?"!D;R!["B`@("`@("`@("`@(&UY("1K97D["B`@("`@("`@("`@
M(&9O<F5A8V@@*&ME>7,@)7)E<75I<F5?;&ES="D@>PH@("`@("`@("`@("`@
M("`@;F5X="!U;FQE<W,@+UQ1)&UO9'5L95Q%)"\["B`@("`@("`@("`@("`@
M("`D:V5Y(#T@)%\[(&QA<W0["B`@("`@("`@("`@('T*("`@("`@("`@("`@
M9&5L971E("1R97%U:7)E7VQI<W1[)&ME>7T@:68@9&5F:6YE9"@D:V5Y*3L*
M("`@("`@("!](&]R(')E='5R;CL*"B`@("`@("`@)$E.0WLD;6]D=6QE?2`]
M("(O;&]A9&5R+R1F:6QE;F%M92\D;6]D=6QE(CL*"B`@("`@("`@:68@*"1%
M3E9[4$%27T-,14%.?2!A;F0@9&5F:6YE9"@F24\Z.D9I;&4Z.FYE=RDI('L*
M("`@("`@("`@("`@;7D@)&9H(#T@24\Z.D9I;&4M/FYE=U]T;7!F:6QE(&]R
M(&1I92`D(3L*("`@("`@("`@("`@8FEN;6]D92@D9F@I.PH@("`@("`@("`@
M("!P<FEN="`D9F@@)&9I;&5N86UE+3Y[8G5F?3L*("`@("`@("`@("`@<V5E
M:R@D9F@L(#`L(#`I.PH@("`@("`@("`@("!R971U<FX@)&9H.PH@("`@("`@
M('T*("`@("`@("!E;'-E('L*("`@("`@("`@("`@;7D@*"1O=70L("1N86UE
M*2`](%]T96UP9FEL92@G+G!M)RP@)&9I;&5N86UE+3Y[8W)C?2D["B`@("`@
M("`@("`@(&EF("@D;W5T*2!["B`@("`@("`@("`@("`@("!B:6YM;V1E*"1O
M=70I.PH@("`@("`@("`@("`@("`@<')I;G0@)&]U="`D9FEL96YA;64M/GMB
M=69].PH@("`@("`@("`@("`@("`@8VQO<V4@)&]U=#L*("`@("`@("`@("`@
M?0H@("`@("`@("`@("!O<&5N(&UY("1F:"P@)SPG+"`D;F%M92!O<B!D:64@
M)"$["B`@("`@("`@("`@(&)I;FUO9&4H)&9H*3L*("`@("`@("`@("`@<F5T
M=7)N("1F:#L*("`@("`@("!]"@H@("`@("`@(&1I92`B0F]O='-T<F%P<&EN
M9R!F86EL960Z(&-A;FYO="!F:6YD("1M;V1U;&4A7&XB.PH@("`@?2P@0$E.
M0RD["@H@("`@(R!.;W<@;&]A9"!A;&P@8G5N9&QE9"!F:6QE<R![>WL*"B`@
M("`C(&EN:71I86QI>F4@<VAA<F5D(&]B:F5C="!P<F]C97-S:6YG"B`@("!R
M97%U:7)E(%A33&]A9&5R.PH@("`@<F5Q=6ER92!005(Z.DAE879Y.PH@("`@
M<F5Q=6ER92!#87)P.CI(96%V>3L*("`@(')E<75I<F4@17AP;W)T97(Z.DAE
M879Y.PH@("`@4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PH*("`@
M(",@;F]W(&QE="=S('1R>2!G971T:6YG(&AE;'!E<B!M;V1U;&5S(&9R;VT@
M=VET:&EN"B`@("!R97%U:7)E($E/.CI&:6QE.PH*("`@(",@;&]A9"!R97-T
M(&]F('1H92!G<F]U<"!I;@H@("`@=VAI;&4@*&UY("1F:6QE;F%M92`]("AS
M;W)T(&ME>7,@)7)E<75I<F5?;&ES="E;,%TI('L*("`@("`@("`C;&]C86P@
M)$E.0WLG0W=D+G!M)WT@/2!?7T9)3$5?7R!I9B`D7D\@;F4@)TU35VEN,S(G
M.PH@("`@("`@('5N;&5S<R`H)$E.0WLD9FEL96YA;65](&]R("1F:6QE;F%M
M92`]?B`O0E-$4$%.+RD@>PH@("`@("`@("`@("`C(')E<75I<F4@;6]D=6QE
M<RP@9&\@;W1H97(@97AE8W5T86)L92!F:6QE<PH@("`@("`@("`@("!I9B`H
M)&9I;&5N86UE(#U^("]<+G!M8S\D+VDI('L*("`@("`@("`@("`@("`@(')E
M<75I<F4@)&9I;&5N86UE.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&5L
M<V4@>PH@("`@("`@("`@("`@("`@(R!3:VEP($%C=&EV95-T871E)W,@<VET
M96-U<W1O;6EZ92YP;"!F:6QE.@H@("`@("`@("`@("`@("`@9&\@)&9I;&5N
M86UE('5N;&5S<R`D9FEL96YA;64@/7X@+W-I=&5C=7-T;VUI>F5<+G!L)"\[
M"B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@9&5L971E("1R97%U
M:7)E7VQI<W1[)&9I;&5N86UE?3L*("`@('T*"B`@("`C('U]?0H*("`@(&QA
M<W0@=6YL97-S("1B=68@97$@(E!+7#`P,UPP,#0B.PH@("`@)'-T87)T7W!O
M<R`]("AT96QL(%]&2"D@+2`T.PI]"B,@?7U]"@HC($%R9W5M96YT('!R;V-E
M<W-I;F<@>WM["FUY($!P87)?87)G<SL*;7D@*"1O=70L("1B=6YD;&4L("1L
M;V=F:"P@)&-A8VAE7VYA;64I.PH*9&5L971E("1%3E9[4$%27T%04%]21553
M17T[(",@<V%N:71I>F4@*%)%55-%(&UA>2!B92!A('-E8W5R:71Y('!R;V)L
M96TI"@HD<75I970@/2`P('5N;&5S<R`D14Y6>U!!4E]$14)51WT["B,@1&]N
M)W0@<W=A;&QO=R!A<F=U;65N=',@9F]R(&-O;7!I;&5D(&5X96-U=&%B;&5S
M('=I=&AO=70@+2UP87(M;W!T:6]N<PII9B`H(21S=&%R=%]P;W,@;W(@*"1!
M4D=66S!=(&5Q("<M+7!A<BUO<'1I;VYS)R`F)B!S:&EF="DI('L*("`@(&UY
M("5D:7-T7V-M9"`]('%W*`H@("`@("`@('`@("!B;&EB7W1O7W!A<@H@("`@
M("`@(&D@("!I;G-T86QL7W!A<@H@("`@("`@('4@("!U;FEN<W1A;&Q?<&%R
M"B`@("`@("`@<R`@('-I9VY?<&%R"B`@("`@("`@=B`@('9E<FEF>5]P87(*
M("`@("D["@H@("`@(R!I9B!T:&4@87!P(&ES(&EN=F]K960@87,@(F%P<&YA
M;64@+2UP87(M;W!T:6]N<R`M+7)E=7-E(%!23T=204T@0%!23T=?05)'5B(L
M"B`@("`C('5S92!T:&4@87!P('1O(')U;B!T:&4@9VEV96X@<&5R;"!C;V1E
M(&EN<W1E860@;V8@86YY=&AI;F<@9G)O;2!T:&4*("`@(",@87!P(&ET<V5L
M9B`H8G5T('-T:6QL('-E="!U<"!T:&4@;F]R;6%L(&%P<"!E;G9I<F]N;65N
M="!A;F0@0$E.0RD*("`@(&EF("A`05)'5B!A;F0@)$%21U9;,%T@97$@)RTM
M<F5U<V4G*2!["B`@("`@("`@<VAI9G0@0$%21U8["B`@("`@("`@)$5.5GM0
M05)?05!07U)%55-%?2`]('-H:69T($!!4D=6.PH@("`@?0H@("`@96QS92![
M(",@;F]R;6%L('!A<FP@8F5H879I;W5R"@H@("`@("`@(&UY($!A9&1?=&]?
M:6YC.PH@("`@("`@('=H:6QE("A`05)'5BD@>PH@("`@("`@("`@("`D05)'
M5ELP72`]?B`O7BTH6T%)34]"3&)Q<&EU<U1V72DH+BHI+R!O<B!L87-T.PH*
M("`@("`@("`@("`@:68@*"0Q(&5Q("=))RD@>PH@("`@("`@("`@("`@("`@
M<'5S:"!`861D7W1O7VEN8RP@)#(["B`@("`@("`@("`@('T*("`@("`@("`@
M("`@96QS:68@*"0Q(&5Q("=-)RD@>PH@("`@("`@("`@("`@("`@979A;"`B
M=7-E("0R(CL*("`@("`@("`@("`@?0H@("`@("`@("`@("!E;'-I9B`H)#$@
M97$@)T$G*2!["B`@("`@("`@("`@("`@("!U;G-H:69T($!P87)?87)G<RP@
M)#(["B`@("`@("`@("`@('T*("`@("`@("`@("`@96QS:68@*"0Q(&5Q("=/
M)RD@>PH@("`@("`@("`@("`@("`@)&]U="`]("0R.PH@("`@("`@("`@("!]
M"B`@("`@("`@("`@(&5L<VEF("@D,2!E<2`G8B<I('L*("`@("`@("`@("`@
M("`@("1B=6YD;&4@/2`G<VET92<["B`@("`@("`@("`@('T*("`@("`@("`@
M("`@96QS:68@*"0Q(&5Q("=")RD@>PH@("`@("`@("`@("`@("`@)&)U;F1L
M92`]("=A;&PG.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&5L<VEF("@D
M,2!E<2`G<2<I('L*("`@("`@("`@("`@("`@("1Q=6EE="`](#$["B`@("`@
M("`@("`@('T*("`@("`@("`@("`@96QS:68@*"0Q(&5Q("=,)RD@>PH@("`@
M("`@("`@("`@("`@;W!E;B`D;&]G9F@L("(^/B(L("0R(&]R(&1I92`B6%A8
M.B!#86YN;W0@;W!E;B!L;V<Z("0A(CL*("`@("`@("`@("`@?0H@("`@("`@
M("`@("!E;'-I9B`H)#$@97$@)U0G*2!["B`@("`@("`@("`@("`@("`D8V%C
M:&5?;F%M92`]("0R.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("!S:&EF
M="A`05)'5BD["@H@("`@("`@("`@("!I9B`H;7D@)&-M9"`]("1D:7-T7V-M
M9'LD,7TI('L*("`@("`@("`@("`@("`@(&1E;&5T92`D14Y6>R=005)?5$5-
M4"=].PH@("`@("`@("`@("`@("`@:6YI=%]I;F,H*3L*("`@("`@("`@("`@
M("`@(')E<75I<F4@4$%2.CI$:7-T.PH@("`@("`@("`@("`@("`@)GLB4$%2
M.CI$:7-T.CHD8VUD(GTH*2!U;FQE<W,@0$%21U8["B`@("`@("`@("`@("`@
M("`F>R)005(Z.D1I<W0Z.B1C;60B?2@D7RD@9F]R($!!4D=6.PH@("`@("`@
M("`@("`@("`@97AI=#L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@
M("`@=6YS:&EF="!`24Y#+"!`861D7W1O7VEN8SL*("`@('T*?0H*(R!86%@@
M+2T@861D("TM<&%R+61E8G5G('-U<'!O<G0A"@HC('U]?0H*(R!/=71P=70@
M;6]D92`H+4\I(&AA;F1L:6YG('M[>PII9B`H)&]U="D@>PH@("`@>PH@("`@
M("`@("-L;V-A;"`D24Y#>R=#=V0N<&TG?2`](%]?1DE,15]?(&EF("1>3R!N
M92`G35-7:6XS,B<["B`@("`@("`@<F5Q=6ER92!)3SHZ1FEL93L*("`@("`@
M("!R97%U:7)E($%R8VAI=F4Z.EII<#L*("`@('T*"B`@("!M>2`D<&%R(#T@
M<VAI9G0H0$%21U8I.PH@("`@;7D@)'II<#L*"@H@("`@:68@*&1E9FEN960@
M)'!A<BD@>PH@("`@("`@(&]P96X@;7D@)&9H+"`G/"<L("1P87(@;W(@9&EE
M(")#86YN;W0@9FEN9"`G)'!A<B<Z("0A(CL*("`@("`@("!B:6YM;V1E*"1F
M:"D["B`@("`@("`@8FQE<W,H)&9H+"`G24\Z.D9I;&4G*3L*"B`@("`@("`@
M)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PH@("`@("`@("@@)'II<"T^<F5A
M9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!A<BD@/3T@07)C:&EV93HZ6FEP.CI!
M6E]/2R@I("D*("`@("`@("`@("`@;W(@9&EE(")296%D("<D<&%R)R!E<G)O
M<CH@)"$B.PH@("`@?0H*"B`@("!M>2`E96YV(#T@9&\@>PH@("`@("`@(&EF
M("@D>FEP(&%N9"!M>2`D;65T82`]("1Z:7`M/F-O;G1E;G1S*"=-151!+GEM
M;"<I*2!["B`@("`@("`@("`@("1M971A(#U^(',O+BI><&%R.B0O+VUS.PH@
M("`@("`@("`@("`D;65T82`]?B!S+UY<4RXJ+R]M<SL*("`@("`@("`@("`@
M)&UE=&$@/7X@+UX@("A;7CI=*RDZ("@N*RDD+VUG.PH@("`@("`@('T*("`@
M('T["@H@("`@(R!/<&5N(&EN<'5T(&%N9"!O=71P=70@9FEL97,@>WM["B`@
M("!L;V-A;"`D+R`](%PT.PH*("`@(&EF("AD969I;F5D("1P87(I('L*("`@
M("`@("!O<&5N(%!!4BP@)SPG+"`D<&%R(&]R(&1I92`B)"$Z("1P87(B.PH@
M("`@("`@(&)I;FUO9&4H4$%2*3L*("`@("`@("!D:64@(B1P87(@:7,@;F]T
M(&$@4$%2(&9I;&4B('5N;&5S<R`\4$%2/B!E<2`B4$M<,#`S7#`P-"(["B`@
M("!]"@H@("`@0W)E871E4&%T:"@D;W5T*2`["B`@("`*("`@(&UY("1F:"`]
M($E/.CI&:6QE+3YN97<H"B`@("`@("`@)&]U="P*("`@("`@("!)3SHZ1FEL
M93HZ3U]#4D5!5"@I('P@24\Z.D9I;&4Z.D]?5U)/3DQ9*"D@?"!)3SHZ1FEL
M93HZ3U]44E5.0R@I+`H@("`@("`@(#`W-S<L"B`@("`I(&]R(&1I92`D(3L*
M("`@(&)I;FUO9&4H)&9H*3L*"B`@("`D+R`]("AD969I;F5D("1D871A7W!O
M<RD@/R!<)&1A=&%?<&]S(#H@=6YD968["B`@("!S965K(%]&2"P@,"P@,#L*
M("`@(&UY("1L;V%D97(@/2!S8V%L87(@/%]&2#X["B`@("!I9B`H(21%3E9[
M4$%27U9%4D)!5$E-?2!A;F0@)&QO861E<B`]?B`O7B@_.B,A?%Q`<F5M*2\I
M('L*("`@("`@("!R97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*("`@
M("`@("!005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/FYE=RT^87!P;'DH7"1L;V%D
M97(L("0P*0H@("`@?0H@("`@9F]R96%C:"!M>2`D:V5Y("AS;W)T(&ME>7,@
M)65N=BD@>PH@("`@("`@(&UY("1V86P@/2`D96YV>R1K97E](&]R(&YE>'0[
M"B`@("`@("`@)'9A;"`](&5V86P@)'9A;"!I9B`D=F%L(#U^("]>6R<B72\[
M"B`@("`@("`@;7D@)&UA9VEC(#T@(E]?14Y67U!!4E\B("X@=6,H)&ME>2D@
M+B`B7U\B.PH@("`@("`@(&UY("1S970@/2`B4$%27R(@+B!U8R@D:V5Y*2`N
M("(])'9A;"(["B`@("`@("`@)&QO861E<B`]?B!S>R1M86=I8R@@*RE]>PH@
M("`@("`@("`@("`D;6%G:6,@+B`D<V5T("X@*"<@)R!X("AL96YG=&@H)#$I
M("T@;&5N9W1H*"1S970I*2D*("`@("`@("!]96<["B`@("!]"B`@("`D9F@M
M/G!R:6YT*"1L;V%D97(I.PH@("`@)"\@/2!U;F1E9CL*("`@(",@?7U]"@H@
M("`@(R!7<FET92!B=6YD;&5D(&UO9'5L97,@>WM["B`@("!I9B`H)&)U;F1L
M92D@>PH@("`@("`@(')E<75I<F4@4$%2.CI(96%V>3L*("`@("`@("!005(Z
M.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["B`@("`@("`@:6YI=%]I;F,H
M*3L*"B`@("`@("`@<F5Q=6ER95]M;V1U;&5S*"D["@H@("`@("`@(&UY($!I
M;F,@/2!S;W)T('L*("`@("`@("`@("`@;&5N9W1H*"1B*2`\/3X@;&5N9W1H
M*"1A*0H@("`@("`@('T@9W)E<"!["B`@("`@("`@("`@("$O0E-$4$%.+PH@
M("`@("`@('T@9W)E<"!["B`@("`@("`@("`@("@D8G5N9&QE(&YE("=S:71E
M)RD@;W(*("`@("`@("`@("`@*"1?(&YE("1#;VYF:6<Z.D-O;F9I9WMA<F-H
M;&EB97AP?2!A;F0*("`@("`@("`@("`@("1?(&YE("1#;VYF:6<Z.D-O;F9I
M9WMP<FEV;&EB97AP?2D["B`@("`@("`@?2!`24Y#.PH*("`@("`@("`C($9I
M;&4@97AI<W1S('1E<W0@861D960@=&\@9FEX(%)4(",T,3<Y,#H*("`@("`@
M("`C($9U;FYY+"!N;VXM97AI<W1I;F<@96YT<GD@:6X@7SPN+BXN875T;R]#
M;VUP<F5S<R]287<O6FQI8B]A=71O<W!L:70N:7@N"B`@("`@("`@(R!4:&ES
M(&ES(&$@8F%N9"UA:60@9FEX('=I=&@@;F\@9&5E<&5R(&=R87-P(&]F('1H
M92!I<W-U92X*("`@("`@("`C(%-O;65B;V1Y('!L96%S92!G;R!T:')O=6=H
M('1H92!P86EN(&]F('5N9&5R<W1A;F1I;F<@=VAA="=S(&AA<'!E;FEN9RP*
M("`@("`@("`C($D@9F%I;&5D+B`M+2!3=&5F9F5N"B`@("`@("`@;7D@)69I
M;&5S.PH@("`@("`@("]>7SPH+BLI)"\@86YD("UE("0Q(&%N9"`D9FEL97-[
M)#%]*RL@9F]R(&ME>7,@)3HZ.PH@("`@("`@("1F:6QE<WLD7WTK*R!F;W(@
M=F%L=65S("5)3D,["@H@("`@("`@(&UY("1L:6)?97AT(#T@)$-O;F9I9SHZ
M0V]N9FEG>VQI8E]E>'1].PH@("`@("`@(&UY("5W<FET=&5N.PH*("`@("`@
M("!F;W)E86-H("AS;W)T(&ME>7,@)69I;&5S*2!["B`@("`@("`@("`@(&UY
M("@D;F%M92P@)&9I;&4I.PH*("`@("`@("`@("`@9F]R96%C:"!M>2`D9&ER
M("A`:6YC*2!["B`@("`@("`@("`@("`@("!I9B`H)&YA;64@/2`D4$%2.CI(
M96%V>3HZ1G5L;$-A8VAE>R1??2D@>PH@("`@("`@("`@("`@("`@("`@("1F
M:6QE(#T@)%\["B`@("`@("`@("`@("`@("`@("`@;&%S=#L*("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@(&5L<VEF("@O7BA<421D:7)<15PO
M*"XJ6UY#8UTI*5Q:+VDI('L*("`@("`@("`@("`@("`@("`@("`H)&9I;&4L
M("1N86UE*2`]("@D,2P@)#(I.PH@("`@("`@("`@("`@("`@("`@(&QA<W0[
M"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!E;'-I9B`H;2%>
M+VQO861E<B];7B]=*R\H+BI;7D-C72E<6B$I('L*("`@("`@("`@("`@("`@
M("`@("!I9B`H;7D@)')E9B`]("1005(Z.DAE879Y.CI-;V1U;&5#86-H97LD
M,7TI('L*("`@("`@("`@("`@("`@("`@("`@("`@*"1F:6QE+"`D;F%M92D@
M/2`H)')E9BP@)#$I.PH@("`@("`@("`@("`@("`@("`@("`@("!L87-T.PH@
M("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("!E;'-I
M9B`H+68@(B1D:7(O)#$B*2!["B`@("`@("`@("`@("`@("`@("`@("`@("@D
M9FEL92P@)&YA;64I(#T@*"(D9&ER+R0Q(BP@)#$I.PH@("`@("`@("`@("`@
M("`@("`@("`@("!L87-T.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@?0H*("`@("`@("`@("`@;F5X="!U
M;FQE<W,@9&5F:6YE9"`D;F%M92!A;F0@;F]T("1W<FET=&5N>R1N86UE?2LK
M.PH@("`@("`@("`@("!N97AT(&EF("%R968H)&9I;&4I(&%N9"`D9FEL92`]
M?B`O7"Y<421L:6)?97AT7$4D+SL*("`@("`@("`@("`@;W5T<R@@:F]I;B`B
M(BP*("`@("`@("`@("`@("`@('%Q*%!A8VMI;F<@(BDL(')E9B`D9FEL92`_
M("1F:6QE+3Y[;F%M97T@.B`D9FEL92P*("`@("`@("`@("`@("`@('%Q*"(N
M+BXI"B`@("`@("`@("`@("D["@H@("`@("`@("`@("!M>2`D8V]N=&5N=#L*
M("`@("`@("`@("`@:68@*')E9B@D9FEL92DI('L*("`@("`@("`@("`@("`@
M("1C;VYT96YT(#T@)&9I;&4M/GMB=69].PH@("`@("`@("`@("!]"B`@("`@
M("`@("`@(&5L<V4@>PH@("`@("`@("`@("`@("`@;W!E;B!&24Q%+"`G/"<L
M("1F:6QE(&]R(&1I92`B0V%N)W0@;W!E;B`D9FEL93H@)"$B.PH@("`@("`@
M("`@("`@("`@8FEN;6]D92A&24Q%*3L*("`@("`@("`@("`@("`@("1C;VYT
M96YT(#T@/$9)3$4^.PH@("`@("`@("`@("`@("`@8VQO<V4@1DE,13L*"B`@
M("`@("`@("`@("`@("!005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/FYE=RT^87!P
M;'DH7"1C;VYT96YT+"`D9FEL92D*("`@("`@("`@("`@("`@("`@("!I9B`A
M)$5.5GM005)?5D520D%424U](&%N9"`D;F%M92`]?B`O7"XH/SIP;7QI>'QA
M;"DD+VD["@H@("`@("`@("`@("`@("`@4$%2.CI&:6QT97(Z.E!A=&-H0V]N
M=&5N="T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE+"`D;F%M92D["B`@
M("`@("`@("`@('T*"B`@("`@("`@("`@(&]U=',H<7$H5W)I='1E;B!A<R`B
M)&YA;64B*2D["B`@("`@("`@("`@("1F:"T^<')I;G0H(D9)3$4B*3L*("`@
M("`@("`@("`@)&9H+3YP<FEN="AP86-K*"=.)RP@;&5N9W1H*"1N86UE*2`K
M(#DI*3L*("`@("`@("`@("`@)&9H+3YP<FEN="AS<')I;G1F*`H@("`@("`@
M("`@("`@("`@(B4P.'@O)7,B+"!!<F-H:79E.CI::7`Z.F-O;7!U=&5#4D,S
M,B@D8V]N=&5N="DL("1N86UE"B`@("`@("`@("`@("DI.PH@("`@("`@("`@
M("`D9F@M/G!R:6YT*'!A8VLH)TXG+"!L96YG=&@H)&-O;G1E;G0I*2D["B`@
M("`@("`@("`@("1F:"T^<')I;G0H)&-O;G1E;G0I.PH@("`@("`@('T*("`@
M('T*("`@(",@?7U]"@H@("`@(R!.;W<@=W)I=&4@;W5T('1H92!005(@86YD
M(&UA9VEC('-T<FEN9W,@>WM["B`@("`D>FEP+3YW<FET951O1FEL94AA;F1L
M92@D9F@I(&EF("1Z:7`["@H@("`@)&-A8VAE7VYA;64@/2!S=6)S='(@)&-A
M8VAE7VYA;64L(#`L(#0P.PH@("`@:68@*"$D8V%C:&5?;F%M92!A;F0@;7D@
M)&UT:6UE(#T@*'-T870H)&]U="DI6SE=*2!["B`@("`@("`@;7D@)&-T>"`]
M(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!.R!$:6=E<W0Z.E-(02T^;F5W
M*#$I('T*("`@("`@("`@("`@?'P@979A;"![(')E<75I<F4@1&EG97-T.CI3
M2$$Q.R!$:6=E<W0Z.E-(03$M/FYE=R!]"B`@("`@("`@("`@('Q\(&5V86P@
M>R!R97%U:7)E($1I9V5S=#HZ340U.R!$:6=E<W0Z.DU$-2T^;F5W('T["@H@
M("`@("`@(",@5V]R:V%R;W5N9"!F;W(@8G5G(&EN($1I9V5S=#HZ4TA!(#4N
M,S@@86YD(#4N,SD*("`@("`@("!M>2`D<VAA7W9E<G-I;VX@/2!E=F%L('L@
M)$1I9V5S=#HZ4TA!.CI615)324].('T@?'P@,#L*("`@("`@("!I9B`H)'-H
M85]V97)S:6]N(&5Q("<U+C,X)R!O<B`D<VAA7W9E<G-I;VX@97$@)S4N,SDG
M*2!["B`@("`@("`@("`@("1C='@M/F%D9&9I;&4H)&]U="P@(F(B*2!I9B`H
M)&-T>"D["B`@("`@("`@?0H@("`@("`@(&5L<V4@>PH@("`@("`@("`@("!I
M9B`H)&-T>"!A;F0@;W!E;BAM>2`D9F@L("(\)&]U="(I*2!["B`@("`@("`@
M("`@("`@("!B:6YM;V1E*"1F:"D["B`@("`@("`@("`@("`@("`D8W1X+3YA
M9&1F:6QE*"1F:"D["B`@("`@("`@("`@("`@("!C;&]S92@D9F@I.PH@("`@
M("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`D8V%C:&5?;F%M92`]("1C
M='@@/R`D8W1X+3YH97AD:6=E<W0@.B`D;71I;64["B`@("!]"B`@("`D8V%C
M:&5?;F%M92`N/2`B7#`B('@@*#0Q("T@;&5N9W1H("1C86-H95]N86UE*3L*
M("`@("1C86-H95]N86UE("X](")#04-(12(["B`@("`D9F@M/G!R:6YT*"1C
M86-H95]N86UE*3L*("`@("1F:"T^<')I;G0H<&%C:R@G3B<L("1F:"T^=&5L
M;"`M(&QE;F=T:"@D;&]A9&5R*2DI.PH@("`@)&9H+3YP<FEN="@B7&Y005(N
M<&U<;B(I.PH@("`@)&9H+3YC;&]S93L*("`@(&-H;6]D(#`W-34L("1O=70[
M"B`@("`C('U]?0H*("`@(&5X:70["GT*(R!]?7T*"B,@4')E<&%R92`D<')O
M9VYA;64@:6YT;R!005(@9FEL92!C86-H92![>WL*>PH@("`@;&%S="!U;FQE
M<W,@9&5F:6YE9"`D<W1A<G1?<&]S.PH*("`@(%]F:7A?<')O9VYA;64H*3L*
M"B`@("`C($YO=R!L;V%D('1H92!005(@9FEL92!A;F0@<'5T(&ET(&EN=&\@
M4$%2.CI,:6)#86-H92![>WL*("`@(')E<75I<F4@4$%2.PH@("`@4$%2.CI(
M96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PH*"B`@("!["B`@("`@("`@(VQO
M8V%L("1)3D-[)T-W9"YP;2=](#T@7U]&24Q%7U\@:68@)%Y/(&YE("=-4U=I
M;C,R)SL*("`@("`@("!R97%U:7)E($9I;&4Z.D9I;F0["B`@("`@("`@<F5Q
M=6ER92!!<F-H:79E.CI::7`["B`@("!]"B`@("!M>2`D>FEP(#T@07)C:&EV
M93HZ6FEP+3YN97<["B`@("!M>2`D9F@@/2!)3SHZ1FEL92T^;F5W.PH@("`@
M)&9H+3YF9&]P96XH9FEL96YO*%]&2"DL("=R)RD@;W(@9&EE("(D(3H@)$`B
M.PH@("`@)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!R;V=N86UE
M*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@;W(@9&EE("(D(3H@)$`B.PH*
M("`@('!U<V@@0%!!4CHZ3&EB0V%C:&4L("1Z:7`["B`@("`D4$%2.CI,:6)#
M86-H97LD<')O9VYA;65](#T@)'II<#L*"B`@("`D<75I970@/2`A)$5.5GM0
M05)?1$5"54=].PH@("`@;W5T<RAQ<2A<)$5.5GM005)?5$5-4'T@/2`B)$5.
M5GM005)?5$5-4'TB*2D["@H@("`@:68@*&1E9FEN960@)$5.5GM005)?5$5-
M4'TI('L@(R!S:&]U;&0@8F4@<V5T(&%T('1H:7,@<&]I;G0A"B`@("`@("`@
M9F]R96%C:"!M>2`D;65M8F5R("@@)'II<"T^;65M8F5R<R`I('L*("`@("`@
M("`@("`@;F5X="!I9B`D;65M8F5R+3YI<T1I<F5C=&]R>3L*("`@("`@("`@
M("`@;7D@)&UE;6)E<E]N86UE(#T@)&UE;6)E<BT^9FEL94YA;64["B`@("`@
M("`@("`@(&YE>'0@=6YL97-S("1M96UB97)?;F%M92`]?B!M>PH@("`@("`@
M("`@("`@("`@7@H@("`@("`@("`@("`@("`@+S]S:&QI8B\*("`@("`@("`@
M("`@("`@("@_.B1#;VYF:6<Z.D-O;F9I9WMV97)S:6]N?2\I/PH@("`@("`@
M("`@("`@("`@*#\Z)$-O;F9I9SHZ0V]N9FEG>V%R8VAN86UE?2\I/PH@("`@
M("`@("`@("`@("`@*%M>+UTK*0H@("`@("`@("`@("`@("`@)`H@("`@("`@
M("`@("!]>#L*("`@("`@("`@("`@;7D@)&5X=')A8W1?;F%M92`]("0Q.PH@
M("`@("`@("`@("!M>2`D9&5S=%]N86UE(#T@1FEL93HZ4W!E8RT^8V%T9FEL
M92@D14Y6>U!!4E]414U0?2P@)&5X=')A8W1?;F%M92D["B`@("`@("`@("`@
M(&EF("@M9B`D9&5S=%]N86UE("8F("US(%\@/3T@)&UE;6)E<BT^=6YC;VUP
M<F5S<V5D4VEZ92@I*2!["B`@("`@("`@("`@("`@("!O=71S*'%Q*%-K:7!P
M:6YG("(D;65M8F5R7VYA;64B('-I;F-E(&ET(&%L<F5A9'D@97AI<W1S(&%T
M("(D9&5S=%]N86UE(BDI.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`@("`@;W5T<RAQ<2A%>'1R86-T:6YG("(D;65M8F5R7VYA;64B('1O
M("(D9&5S=%]N86UE(BDI.PH@("`@("`@("`@("`@("`@)&UE;6)E<BT^97AT
M<F%C=%1O1FEL94YA;65D*"1D97-T7VYA;64I.PH@("`@("`@("`@("`@("`@
M8VAM;V0H,#4U-2P@)&1E<W1?;F%M92D@:68@)%Y/(&5Q(")H<'5X(CL*("`@
M("`@("`@("`@?0H@("`@("`@('T*("`@('T*("`@(",@?7U]"GT*(R!]?7T*
M"B,@268@=&AE<F4G<R!N;R!M86EN+G!L('1O(')U;BP@<VAO=R!U<V%G92![
M>WL*=6YL97-S("@D4$%2.CI,:6)#86-H97LD<')O9VYA;65]*2!["B`@("!D
M:64@/#P@(BXB('5N;&5S<R!`05)'5CL*57-A9V4Z("0P(%L@+4%L:6(N<&%R
M(%T@6R`M261I<B!=(%L@+4UM;V1U;&4@72!;('-R8RYP87(@72!;('!R;V=R
M86TN<&P@70H@("`@("`@)#`@6R`M0GPM8B!=(%LM3V]U=&9I;&5=('-R8RYP
M87(*+@H@("`@)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE(#T@)#`@
M/2!S:&EF="A`05)'5BD["GT*(R!]?7T*"G-U8B!#<F5A=&50871H('L*("`@
M(&UY("@D;F%M92D@/2!`7SL*("`@(`H@("`@<F5Q=6ER92!&:6QE.CI"87-E
M;F%M93L*("`@(&UY("@D8F%S96YA;64L("1P871H+"`D97AT*2`]($9I;&4Z
M.D)A<V5N86UE.CIF:6QE<&%R<V4H)&YA;64L("@G7"XN*B<I*3L*("`@(`H@
M("`@<F5Q=6ER92!&:6QE.CI0871H.PH@("`@"B`@("!&:6QE.CI0871H.CIM
M:W!A=&@H)'!A=&@I('5N;&5S<R@M92`D<&%T:"D[(",@;6MP871H(&1I97,@
M=VET:"!E<G)O<@I]"@IS=6(@<F5Q=6ER95]M;V1U;&5S('L*("`@("-L;V-A
M;"`D24Y#>R=#=V0N<&TG?2`](%]?1DE,15]?(&EF("1>3R!N92`G35-7:6XS
M,B<["@H@("`@<F5Q=6ER92!L:6(["B`@("!R97%U:7)E($1Y;F%,;V%D97([
M"B`@("!R97%U:7)E(&EN=&5G97(["B`@("!R97%U:7)E('-T<FEC=#L*("`@
M(')E<75I<F4@=V%R;FEN9W,["B`@("!R97%U:7)E('9A<G,["B`@("!R97%U
M:7)E($-A<G`["B`@("!R97%U:7)E($-A<G`Z.DAE879Y.PH@("`@<F5Q=6ER
M92!%<G)N;SL*("`@(')E<75I<F4@17AP;W)T97(Z.DAE879Y.PH@("`@<F5Q
M=6ER92!%>'!O<G1E<CL*("`@(')E<75I<F4@1F-N=&P["B`@("!R97%U:7)E
M($9I;&4Z.E1E;7`["B`@("!R97%U:7)E($9I;&4Z.E-P96,["B`@("!R97%U
M:7)E(%A33&]A9&5R.PH@("`@<F5Q=6ER92!#;VYF:6<["B`@("!R97%U:7)E
M($E/.CI(86YD;&4["B`@("!R97%U:7)E($E/.CI&:6QE.PH@("`@<F5Q=6ER
M92!#;VUP<F5S<SHZ6FQI8CL*("`@(')E<75I<F4@07)C:&EV93HZ6FEP.PH@
M("`@<F5Q=6ER92!005(["B`@("!R97%U:7)E(%!!4CHZ2&5A=GD["B`@("!R
M97%U:7)E(%!!4CHZ1&ES=#L*("`@(')E<75I<F4@4$%2.CI&:6QT97(Z.E!O
M9%-T<FEP.PH@("`@<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT
M.PH@("`@<F5Q=6ER92!A='1R:6)U=&5S.PH@("`@979A;"![(')E<75I<F4@
M0W=D('T["B`@("!E=F%L('L@<F5Q=6ER92!7:6XS,B!].PH@("`@979A;"![
M(')E<75I<F4@4V-A;&%R.CI5=&EL('T["B`@("!E=F%L('L@<F5Q=6ER92!!
M<F-H:79E.CI5;GII<#HZ0G5R<W0@?3L*("`@(&5V86P@>R!R97%U:7)E(%1I
M93HZ2&%S:#HZ3F%M961#87!T=7)E('T["B`@("!E=F%L('L@<F5Q=6ER92!0
M97)L24\[(')E<75I<F4@4&5R;$E/.CIS8V%L87(@?3L*?0H*(R!4:&4@0R!V
M97)S:6]N(&]F('1H:7,@8V]D92!A<'!E87)S(&EN(&UY;&1R+VUK=&UP9&ER
M+F,*(R!4:&ES(&-O9&4@86QS;R!L:79E<R!I;B!005(Z.E-E='5P5&5M<"!A
M<R!S971?<&%R7W1E;7!?96YV(0IS=6(@7W-E=%]P87)?=&5M<"!["B`@("!I
M9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@
M/7X@+R@N*RDO*2!["B`@("`@("`@)'!A<E]T96UP(#T@)#$["B`@("`@("`@
M<F5T=7)N.PH@("`@?0H*("`@(&9O<F5A8V@@;7D@)'!A=&@@*`H@("`@("`@
M("AM87`@)$5.5GLD7WTL('%W*"!005)?5$U01$E2(%1-4$1)4B!414U01$E2
M(%1%35`@5$U0("DI+`H@("`@("`@('%W*"!#.EQ<5$5-4"`O=&UP("X@*0H@
M("`@*2!["B`@("`@("`@;F5X="!U;FQE<W,@9&5F:6YE9"`D<&%T:"!A;F0@
M+60@)'!A=&@@86YD("UW("1P871H.PH@("`@("`@(&UY("1U<V5R;F%M93L*
M("`@("`@("!M>2`D<'=U:60["B`@("`@("`@(R!D;V5S(&YO="!W;W)K(&5V
M97)Y=VAE<F4Z"B`@("`@("`@979A;"![*"1P=W5I9"D@/2!G971P=W5I9"@D
M/BD@:68@9&5F:6YE9"`D/CM].PH*("`@("`@("!I9B`H(&1E9FEN960H)E=I
M;C,R.CI,;V=I;DYA;64I("D@>PH@("`@("`@("`@("`D=7-E<FYA;64@/2`F
M5VEN,S(Z.DQO9VEN3F%M93L*("`@("`@("!]"B`@("`@("`@96QS:68@*&1E
M9FEN960@)'!W=6ED*2!["B`@("`@("`@("`@("1U<V5R;F%M92`]("1P=W5I
M9#L*("`@("`@("!]"B`@("`@("`@96QS92!["B`@("`@("`@("`@("1U<V5R
M;F%M92`]("1%3E9[55-%4DY!345]('Q\("1%3E9[55-%4GT@?'P@)U-94U1%
M32<["B`@("`@("`@?0H@("`@("`@("1U<V5R;F%M92`]?B!S+UQ7+U\O9SL*
M"B`@("`@("`@;7D@)'-T;7!D:7(@/2`B)'!A=&@D0V]N9FEG>U]D96QI;7UP
M87(M)'5S97)N86UE(CL*("`@("`@("!M:V1I<B`D<W1M<&1I<BP@,#<U-3L*
M("`@("`@("!I9B`H(21%3E9[4$%27T-,14%.?2!A;F0@;7D@)&UT:6UE(#T@
M*'-T870H)'!R;V=N86UE*2E;.5TI('L*("`@("`@("`@("`@;W!E;B`H;7D@
M)&9H+"`B/"(N("1P<F]G;F%M92D["B`@("`@("`@("`@('-E96L@)&9H+"`M
M,3@L(#(["B`@("`@("`@("`@('-Y<W)E860@)&9H+"!M>2`D8G5F+"`V.PH@
M("`@("`@("`@("!I9B`H)&)U9B!E<2`B7#!#04-(12(I('L*("`@("`@("`@
M("`@("`@('-E96L@)&9H+"`M-3@L(#(["B`@("`@("`@("`@("`@("!S>7-R
M96%D("1F:"P@)&)U9BP@-#$["B`@("`@("`@("`@("`@("`D8G5F(#U^(',O
M7#`O+V<["B`@("`@("`@("`@("`@("`D<W1M<&1I<B`N/2`B)$-O;F9I9WM?
M9&5L:6U]8V%C:&4M(B`N("1B=68["B`@("`@("`@("`@('T*("`@("`@("`@
M("`@96QS92!["B`@("`@("`@("`@("`@("!M>2`D8W1X(#T@979A;"![(')E
M<75I<F4@1&EG97-T.CI32$$[($1I9V5S=#HZ4TA!+3YN97<H,2D@?0H@("`@
M("`@("`@("`@("`@("`@('Q\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!
M,3L@1&EG97-T.CI32$$Q+3YN97<@?0H@("`@("`@("`@("`@("`@("`@('Q\
M(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ340U.R!$:6=E<W0Z.DU$-2T^;F5W
M('T["@H@("`@("`@("`@("`@("`@(R!7;W)K87)O=6YD(&9O<B!B=6<@:6X@
M1&EG97-T.CI32$$@-2XS."!A;F0@-2XS.0H@("`@("`@("`@("`@("`@;7D@
M)'-H85]V97)S:6]N(#T@979A;"![("1$:6=E<W0Z.E-(03HZ5D524TE/3B!]
M('Q\(#`["B`@("`@("`@("`@("`@("!I9B`H)'-H85]V97)S:6]N(&5Q("<U
M+C,X)R!O<B`D<VAA7W9E<G-I;VX@97$@)S4N,SDG*2!["B`@("`@("`@("`@
M("`@("`@("`@)&-T>"T^861D9FEL92@D<')O9VYA;64L(")B(BD@:68@*"1C
M='@I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@96QS92![
M"B`@("`@("`@("`@("`@("`@("`@:68@*"1C='@@86YD(&]P96XH;7D@)&9H
M+"`B/"1P<F]G;F%M92(I*2!["B`@("`@("`@("`@("`@("`@("`@("`@(&)I
M;FUO9&4H)&9H*3L*("`@("`@("`@("`@("`@("`@("`@("`@)&-T>"T^861D
M9FEL92@D9F@I.PH@("`@("`@("`@("`@("`@("`@("`@("!C;&]S92@D9F@I
M.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*"B`@
M("`@("`@("`@("`@("`D<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]8V%C
M:&4M(B`N("@@)&-T>"`_("1C='@M/FAE>&1I9V5S="`Z("1M=&EM92`I.PH@
M("`@("`@("`@("!]"B`@("`@("`@("`@(&-L;W-E*"1F:"D["B`@("`@("`@
M?0H@("`@("`@(&5L<V4@>PH@("`@("`@("`@("`D14Y6>U!!4E]#3$5!3GT@
M/2`Q.PH@("`@("`@("`@("`D<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]
M=&5M<"TD)"(["B`@("`@("`@?0H*("`@("`@("`D14Y6>U!!4E]414U0?2`]
M("1S=&UP9&ER.PH@("`@("`@(&UK9&ER("1S=&UP9&ER+"`P-S4U.PH@("`@
M("`@(&QA<W0["B`@("!]"@H@("`@)'!A<E]T96UP(#T@)#$@:68@)$5.5GM0
M05)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+SL*?0H*<W5B
M(%]T96UP9FEL92!["B`@("!M>2`H)&5X="P@)&-R8RD@/2!`7SL*("`@(&UY
M("@D9F@L("1F:6QE;F%M92D["@H@("`@)&9I;&5N86UE(#T@(B1P87)?=&5M
M<"\D8W)C)&5X="(["@H@("`@:68@*"1%3E9[4$%27T-,14%.?2D@>PH@("`@
M("`@('5N;&EN:R`D9FEL96YA;64@:68@+64@)&9I;&5N86UE.PH@("`@("`@
M('!U<V@@0'1M<&9I;&4L("1F:6QE;F%M93L*("`@('T*("`@(&5L<V4@>PH@
M("`@("`@(')E='5R;B`H=6YD968L("1F:6QE;F%M92D@:68@*"UR("1F:6QE
M;F%M92D["B`@("!]"@H@("`@;W!E;B`D9F@L("<^)RP@)&9I;&5N86UE(&]R
M(&1I92`D(3L*("`@(&)I;FUO9&4H)&9H*3L*("`@(')E='5R;B@D9F@L("1F
M:6QE;F%M92D["GT*"B,@<V%M92!C;V1E(&QI=F5S(&EN(%!!4CHZ4V5T=7!0
M<F]G;F%M93HZ<V5T7W!R;V=N86UE"G-U8B!?<V5T7W!R;V=N86UE('L*("`@
M(&EF("AD969I;F5D("1%3E9[4$%27U!23T=.04U%?2!A;F0@)$5.5GM005)?
M4%)/1TY!345](#U^("\H+BLI+RD@>PH@("`@("`@("1P<F]G;F%M92`]("0Q
M.PH@("`@?0H*("`@("1P<F]G;F%M92!\?#T@)#`["@H@("`@:68@*"1%3E9[
M4$%27U1%35!](&%N9"!I;F1E>"@D<')O9VYA;64L("1%3E9[4$%27U1%35!]
M*2`^/2`P*2!["B`@("`@("`@)'!R;V=N86UE(#T@<W5B<W1R*"1P<F]G;F%M
M92P@<FEN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`K(#$I.PH@
M("`@?0H*("`@(&EF("@A)$5.5GM005)?4%)/1TY!345](&]R(&EN9&5X*"1P
M<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`^/2`P*2!["B`@("`@("`@:68@
M*&]P96X@;7D@)&9H+"`G/"<L("1P<F]G;F%M92D@>PH@("`@("`@("`@("!R
M971U<FX@:68@+7,@)&9H.PH@("`@("`@('T*("`@("`@("!I9B`H+7,@(B1P
M<F]G;F%M921#;VYF:6=[7V5X97TB*2!["B`@("`@("`@("`@("1P<F]G;F%M
M92`N/2`D0V]N9FEG>U]E>&5].PH@("`@("`@("`@("!R971U<FX["B`@("`@
M("`@?0H@("`@?0H*("`@(&9O<F5A8V@@;7D@)&1I<B`H<W!L:70@+UQ1)$-O
M;F9I9WMP871H7W-E<'U<12\L("1%3E9[4$%42'TI('L*("`@("`@("!N97AT
M(&EF(&5X:7-T<R`D14Y6>U!!4E]414U0?2!A;F0@)&1I<B!E<2`D14Y6>U!!
M4E]414U0?3L*("`@("`@("`D9&ER(#U^(',O7%$D0V]N9FEG>U]D96QI;7U<
M120O+SL*("`@("`@("`H*"1P<F]G;F%M92`]("(D9&ER)$-O;F9I9WM?9&5L
M:6U])'!R;V=N86UE)$-O;F9I9WM?97AE?2(I+"!L87-T*0H@("`@("`@("`@
M("!I9B`M<R`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M921#;VYF:6=[
M7V5X97TB.PH@("`@("`@("@H)'!R;V=N86UE(#T@(B1D:7(D0V]N9FEG>U]D
M96QI;7TD<')O9VYA;64B*2P@;&%S="D*("`@("`@("`@("`@:68@+7,@(B1D
M:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64B.PH@("`@?0I]"@IS=6(@7V9I
M>%]P<F]G;F%M92!["B`@("`D,"`]("1P<F]G;F%M92!\?#T@)$5.5GM005)?
M4%)/1TY!345].PH@("`@:68@*&EN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?
M9&5L:6U]*2`\(#`I('L*("`@("`@("`D<')O9VYA;64@/2`B+B1#;VYF:6=[
M7V1E;&EM?21P<F]G;F%M92(["B`@("!]"@H@("`@(R!86%@@+2!H86-K('1O
M(&UA:V4@4%=$('=O<FL*("`@(&UY("1P=V0@/2`H9&5F:6YE9"`F0W=D.CIG
M971C=V0I(#\@0W=D.CIG971C=V0H*0H@("`@("`@("`@("`@("`@.B`H*&1E
M9FEN960@)E=I;C,R.CI'971#=V0I(#\@5VEN,S(Z.D=E=$-W9"@I(#H@8'!W
M9&`I.PH@("`@8VAO;7`H)'!W9"D["B`@("`D<')O9VYA;64@/7X@<R]>*#\]
M7"Y<+C]<421#;VYF:6=[7V1E;&EM?5Q%*2\D<'=D)$-O;F9I9WM?9&5L:6U]
M+SL*"B`@("`D14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64["GT*"G-U
M8B!?<&%R7VEN:71?96YV('L*("`@(&EF("@@)$5.5GM005)?24Y)5$E!3$E:
M141]*RL@/3T@,2`I('L*("`@("`@("!R971U<FX["B`@("!](&5L<V4@>PH@
M("`@("`@("1%3E9[4$%27TE.251)04Q)6D5$?2`](#(["B`@("!]"@H@("`@
M9F]R("AQ=R@@4U!!5TY%1"!414U0($-,14%.($1%0E5'($-!0TA%(%!23T=.
M04U%($%21T,@05)'5E\P("D@*2!["B`@("`@("`@9&5L971E("1%3E9[)U!!
M4E\G+B1??3L*("`@('T*("`@(&9O<B`H<7<O(%1-4$1)4B!414U0($-,14%.
M($1%0E5'("\I('L*("`@("`@("`D14Y6>R=005)?)RXD7WT@/2`D14Y6>R=0
M05)?1TQ/0D%,7R<N)%]](&EF(&5X:7-T<R`D14Y6>R=005)?1TQ/0D%,7R<N
M)%]].PH@("`@?0H*("`@(&UY("1P87)?8VQE86X@/2`B7U]%3E9?4$%27T-,
M14%.7U\@("`@("`@("`@("`@("`B.PH*("`@(&EF("@D14Y6>U!!4E]414U0
M?2D@>PH@("`@("`@(&1E;&5T92`D14Y6>U!!4E]#3$5!3GT["B`@("!]"B`@
M("!E;'-I9B`H(65X:7-T<R`D14Y6>U!!4E]'3$]"04Q?0TQ%04Y]*2!["B`@
M("`@("`@;7D@)'9A;'5E(#T@<W5B<W1R*"1P87)?8VQE86XL(#$R("L@;&5N
M9W1H*")#3$5!3B(I*3L*("`@("`@("`D14Y6>U!!4E]#3$5!3GT@/2`D,2!I
M9B`D=F%L=64@/7X@+UY005)?0TQ%04X]*%Q3*RDO.PH@("`@?0I]"@IS=6(@
M;W5T<R!["B`@("!R971U<FX@:68@)'%U:65T.PH@("`@:68@*"1L;V=F:"D@
M>PH@("`@("`@('!R:6YT("1L;V=F:"`B0%]<;B(["B`@("!]"B`@("!E;'-E
M('L*("`@("`@("!P<FEN="`B0%]<;B(["B`@("!]"GT*"G-U8B!I;FET7VEN
M8R!["B`@("!R97%U:7)E($-O;F9I9SL*("`@('!U<V@@0$E.0RP@9W)E<"!D
M969I;F5D+"!M87`@)$-O;F9I9SHZ0V]N9FEG>R1??2P@<7<H"B`@("`@("`@
M87)C:&QI8F5X<"!P<FEV;&EB97AP('-I=&5A<F-H97AP('-I=&5L:6)E>'`*
M("`@("`@("!V96YD;W)A<F-H97AP('9E;F1O<FQI8F5X<`H@("`@*3L*?0H*
M(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C"B,@5&AE(&UA:6X@<&%C:V%G
M92!F;W(@<V-R:7!T(&5X96-U=&EO;@H*<&%C:V%G92!M86EN.PH*<F5Q=6ER
M92!005(["G5N<VAI9G0@0$E.0RP@7"9005(Z.F9I;F1?<&%R.PI005(M/FEM
M<&]R="A`<&%R7V%R9W,I.PH*9&EE('%Q*'!A<BYP;#H@0V%N)W0@;W!E;B!P
M97)L('-C<FEP="`B)'!R;V=N86UE(CH@3F\@<W5C:"!F:6QE(&]R(&1I<F5C
M=&]R>5QN*0H@("`@=6YL97-S("UE("1P<F]G;F%M93L*"F1O("1P<F]G;F%M
M93L*0T]213HZ97AI="@D,2D@:68@*"1`(#U^+UY?5$M?15A)5%]<*"A<9"LI
M7"DO*3L*9&EE("1`(&EF("1`.PH*?3L*"B0Z.E]?15)23U(@/2`D0"!I9B`D
M0#L*?0H*0T]213HZ97AI="@D,2D@:68@*"0Z.E]?15)23U(@/7XO7E]42U]%
M6$E47UPH*%QD*RE<*2\I.PID:64@)#HZ7U]%4E)/4B!I9B`D.CI?7T524D]2
M.PH*,3L*"B-L:6YE(#$P,3$*"E]?14Y$7U\*```````````````!`````0``
M``$```(=`````0```B<````!```"-0````$```)"`````0```F8````/```)
M"0````P!@"3T````#0&`=^@````$`8`!1`````4!@!4L````!@&`![P````*
M```*20````L````0````%0`````````#`8'=$`````(```+0````%`````<`
M```7`8`B)`````<!@"%D````"````Y`````)````#&____X!@"$D;____P``
M``)O___P`8`?=@``````````````````````````````````````````````
M`````````````````/____\`````_____P``````````3H``(0&!V[``````
M``````&`>]0`````````````````)$9R965"4T0Z('-R8R]L:6(O8W-U+V-O
M;6UO;B]C<G1B<F%N9"YC+'8@,2XV+C(N,2XT+C$@,C`Q,"\P-B\Q-"`P,CHP
M.3HP-B!K96YS;6ET:"!%>'`@)``D1G)E94)31#H@<W)C+VQI8B]C<W4O<&]W
M97)P8R]C<G0Q+F,L=B`Q+C$Q+C(R+C$N-"XQ(#(P,3`O,#8O,30@,#(Z,#DZ
M,#8@:V5N<VUI=&@@17AP("0`1T-#.B`H1TY5*2`T+C(N,2`R,#`W,#<Q.2`@
M6T9R965"4T1=``!'0T,Z("A'3E4I(#0N,BXQ(#(P,#<P-S$Y("!;1G)E94)3
M1%T``$=#0SH@*$=.52D@-"XR+C$@,C`P-S`W,3D@(%M&<F5E0E-$70``1T-#
M.B`H1TY5*2`T+C(N,2`R,#`W,#<Q.2`@6T9R965"4T1=```N<VAS=')T86(`
M+FEN=&5R<``N;F]T92Y!0DDM=&%G`"YH87-H`"YD>6YS>6T`+F1Y;G-T<@`N
M9VYU+G9E<G-I;VX`+F=N=2YV97)S:6]N7W(`+G)E;&$N9'EN`"YR96QA+G!L
M=``N:6YI=``N=&5X=``N9FEN:0`N<F]D871A`"YS9&%T83(`+F1A=&$`+F5H
M7V9R86UE`"YD>6YA;6EC`"YC=&]R<P`N9'1O<G,`+FIC<@`N9V]T`"YS9&%T
M80`N<V)S<P`N8G-S`"YC;VUM96YT````````````````````````````````
M``````````````````````````````L````!`````@&``10```$4````%0``
M`````````````0`````````3````!P````(!@`$L```!+````!@`````````
M``````0`````````(0````4````"`8`!1````40```9X````!``````````$
M````!````"<````+`````@&`![P```>\```-<`````4````!````!````!``
M```O`````P````(!@!4L```5+```"DD```````````````$`````````-V__
M__\````"`8`?=@``'W8```&N````!``````````"`````@```$1O___^````
M`@&`(20``"$D````0`````4````"````!`````````!3````!`````(!@"%D
M```A9````,`````$``````````0````,````70````0````"`8`B)```(B0`
M``+0````!````!@````$````#````&<````!````!@&`)/0``"3T````-```
M````````````!`````````!M`````0````8!@"4H```E*```4L``````````
M``````0`````````<P````$````&`8!WZ```=^@````P```````````````$
M`````````'D````!`````@&`>!@``'@8```$S@``````````````"```````
M``"!`````0````(!@'SH``!\Z`````````````````````0`````````B0``
M``$````#`8&`````@````%NL```````````````$`````````(\````!````
M`@&!VZP``-NL````!```````````````!`````````"9````!@````,!@=NP
M``#;L````/@````%``````````0````(````H@````$````#`8'<J```W*@`
M```(```````````````$`````````*D````!`````P&!W+```-RP````"```
M````````````!`````````"P`````0````,!@=RX``#<N`````0`````````
M``````0`````````M0````$````'`8'<O```W+P````0```````````````$
M````!````+H````!`````P&!W,P``-S,````"```````````````!```````
M``#!````"`````,!@=S4``#<U````#P```````````````0`````````8@``
M``@````'`8'=$```W-0```,8```````````````$`````````,<````(````
M`P&!X#```-S<```$2```````````````$`````````#,`````0``````````
M``#<W````4D```````````````$``````````0````,`````````````WB4`
3``#5```````````````!````````
